@@ -4,6 +4,12 @@
 #include "expert.h"
 #include "wizard.h"
 
+#ifdef WIN32
+#include <windows.h>
+#endif
+
+#define MAX_RECENT_FILES 10
+
 const int messageTimeout = 5000; //!< status bar message timeout in millisec.
 
 MainWindow &MainWindow::instance()
@@ -31,6 +37,8 @@ MainWindow::MainWindow()
                   this,SLOT(resetToDefaults()));
   settings->addAction(tr("Use current settings at startup"),
                   this,SLOT(makeDefaults()));
+  settings->addAction(tr("Clear recent list"),
+                  this,SLOT(clearRecent()));
 
   QMenu *help = menuBar()->addMenu(tr("Help"));
   help->addAction(tr("Online manual"), 
@@ -85,10 +93,6 @@ MainWindow::MainWindow()
   m_launchHtml = new QPushButton(tr("Show HTML output"));
   launchLayout->addWidget(m_launchHtml);
 
-#if 0
-  m_launchPdf  = new QPushButton(tr("Show PDF output"));
-  launchLayout->addWidget(m_launchPdf);
-#endif
   launchLayout->addStretch(1);
   grid->addLayout(launchLayout,1,0);
   runTabLayout->addLayout(grid);
@@ -105,14 +109,10 @@ MainWindow::MainWindow()
 
   setCentralWidget(topPart);
   statusBar()->showMessage(tr("Welcome to Doxygen"),messageTimeout);
-  loadSettings();
 
   m_runProcess = new QProcess;
   m_running = false;
   m_timer = new QTimer;
-  updateLaunchButtonState();
-  m_modified = false;
-  updateTitle();
 
   // connect signals and slots
   connect(tabs,SIGNAL(currentChanged(int)),SLOT(selectTab(int)));
@@ -127,6 +127,12 @@ MainWindow::MainWindow()
   connect(m_saveLog,SIGNAL(clicked()),SLOT(saveLog()));
   connect(showSettings,SIGNAL(clicked()),SLOT(showSettings()));
   connect(m_expert,SIGNAL(changed()),SLOT(configChanged()));
+
+  loadSettings();
+  updateLaunchButtonState();
+  m_modified = false;
+  updateTitle();
+  m_wizard->refresh();
 }
 
 void MainWindow::closeEvent(QCloseEvent *event)
@@ -185,7 +191,7 @@ void MainWindow::about()
   t << QString::fromAscii("<qt><center>A tool to configure and run doxygen version ")+
        QString::fromAscii(versionString)+
        QString::fromAscii(" on your source files.</center><p><br>"
-       "<center>Written by<br> Dimitri van Heesch<br>&copy; 2000-2008</center><p>"
+       "<center>Written by<br> Dimitri van Heesch<br>&copy; 2000-2009</center><p>"
        "</qt>");
   QMessageBox::about(this,tr("Doxygen GUI"),msg);
 }
@@ -230,7 +236,14 @@ void MainWindow::saveConfig(const QString &fileName)
 {
   if (fileName.isEmpty()) return;
   QFile f(fileName);
-  if (!f.open(QIODevice::WriteOnly)) return;
+  if (!f.open(QIODevice::WriteOnly)) 
+  {
+    QMessageBox::warning(this,
+        tr("Error saving"),
+        tr("Error: cannot open the file ")+fileName+tr(" for writing!\n")+
+        tr("Reason given: ")+f.error());
+    return;
+  }
   QTextStream t(&f);
   m_expert->writeConfig(t,false);
   updateConfigFileName(fileName);
@@ -271,9 +284,29 @@ void MainWindow::makeDefaults()
     //printf("MainWindow:makeDefaults()\n");
     m_expert->saveSettings(&m_settings);
     m_settings.setValue(QString::fromAscii("wizard/loadsettings"), true);
+    m_settings.sync();
   }
 }
 
+void MainWindow::clearRecent()
+{
+  if (QMessageBox::question(this,tr("Clear the list of recent files?"),
+                        tr("Do you want to clear the list of recently "
+                           "loaded configuration files?"),
+                        QMessageBox::Yes|
+                        QMessageBox::Cancel)==QMessageBox::Yes)
+  {
+    m_recentMenu->clear();
+    m_recentFiles.clear();
+    for (int i=0;i<MAX_RECENT_FILES;i++)
+    {
+      m_settings.setValue(QString().sprintf("recent/config%d",i++),QString::fromAscii(""));
+    }
+    m_settings.sync();
+  }
+  
+}
+
 void MainWindow::resetToDefaults()
 {
   if (QMessageBox::question(this,tr("Reset settings to their default values?"),
@@ -285,6 +318,7 @@ void MainWindow::resetToDefaults()
     //printf("MainWindow:resetToDefaults()\n");
     m_expert->resetToDefaults();
     m_settings.setValue(QString::fromAscii("wizard/loadsettings"), false);
+    m_settings.sync();
     m_wizard->refresh();
   }
 }
@@ -293,33 +327,29 @@ void MainWindow::loadSettings()
 {
   QVariant geometry     = m_settings.value(QString::fromAscii("main/geometry"), QVariant::Invalid);
   QVariant state        = m_settings.value(QString::fromAscii("main/state"),    QVariant::Invalid);
-  //QVariant expState     = m_settings.value(QString::fromAscii("expert/state"),  QVariant::Invalid);
-  //QVariant expState2    = m_settings.value(QString::fromAscii("expert/state2"), QVariant::Invalid);
   QVariant wizState     = m_settings.value(QString::fromAscii("wizard/state"),  QVariant::Invalid);
   QVariant loadSettings = m_settings.value(QString::fromAscii("wizard/loadsettings"),  QVariant::Invalid);
-  //QVariant workingDir   = m_settings.value(QString::fromAscii("main/defdir"),   QVariant::Invalid);
+  QVariant workingDir   = m_settings.value(QString::fromAscii("wizard/workingdir"), QVariant::Invalid);
 
   if (geometry  !=QVariant::Invalid) restoreGeometry(geometry.toByteArray());
   if (state     !=QVariant::Invalid) restoreState   (state.toByteArray());
-  //if (expState  !=QVariant::Invalid) m_expert->restoreState(expState.toByteArray());
-  //if (expState2 !=QVariant::Invalid) m_expert->restoreInnerState(expState2.toByteArray());
   if (wizState  !=QVariant::Invalid) m_wizard->restoreState(wizState.toByteArray());
-  //if (workingDir!=QVariant::Invalid) 
-  //{ 
-  //  QString dir = workingDir.toString();
-  //  m_workingDir->setText(dir);
-  //  QDir::setCurrent(dir);
-  //  m_run->setEnabled(!dir.isEmpty());
-  //}
   if (loadSettings!=QVariant::Invalid && loadSettings.toBool())
   {
     m_expert->loadSettings(&m_settings);
+    if (workingDir!=QVariant::Invalid && QDir(workingDir.toString()).exists())
+    {
+      setWorkingDir(workingDir.toString());
+    }
   }
 
-  for (int i=0;i<10;i++)
+  for (int i=0;i<MAX_RECENT_FILES;i++)
   {
     QString entry = m_settings.value(QString().sprintf("recent/config%d",i)).toString();
-    if (!entry.isEmpty()) addRecentFile(entry);
+    if (!entry.isEmpty() && QFileInfo(entry).exists())
+    {
+      addRecentFile(entry);
+    }
   }
 
 }
@@ -330,9 +360,8 @@ void MainWindow::saveSettings()
 
   m_settings.setValue(QString::fromAscii("main/geometry"), saveGeometry());
   m_settings.setValue(QString::fromAscii("main/state"),    saveState());
-  //m_settings.setValue(QString::fromAscii("expert/state"),  m_expert->saveState());
-  //m_settings.setValue(QString::fromAscii("expert/state2"), m_expert->saveInnerState());
   m_settings.setValue(QString::fromAscii("wizard/state"),  m_wizard->saveState());
+  m_settings.setValue(QString::fromAscii("wizard/workingdir"), m_workingDir->text());
 }
 
 void MainWindow::selectTab(int id)
@@ -346,7 +375,7 @@ void MainWindow::addRecentFile(const QString &fileName)
   if (i!=-1) m_recentFiles.removeAt(i);
   
   // not found
-  if (m_recentFiles.count() < 10) // append
+  if (m_recentFiles.count() < MAX_RECENT_FILES) // append
   {
     m_recentFiles.prepend(fileName);
   }
@@ -362,6 +391,10 @@ void MainWindow::addRecentFile(const QString &fileName)
     m_recentMenu->addAction(str);
     m_settings.setValue(QString().sprintf("recent/config%d",i++),str);
   }
+  for (;i<MAX_RECENT_FILES;i++)
+  {
+    m_settings.setValue(QString().sprintf("recent/config%d",i++),QString::fromAscii(""));
+  }
 }
 
 void MainWindow::openRecent(QAction *action)
@@ -380,15 +413,19 @@ void MainWindow::runDoxygen()
 #if defined(Q_OS_MACX)
     doxygenPath = qApp->applicationDirPath()+QString::fromAscii("/../Resources/");
     qDebug() << tr("Doxygen path: ") << doxygenPath;
-    if ( !QFile(doxygenPath + QString::fromAscii("doxygen")).exists() ) {
-        // No doygen binary in the resources, if there is a system doxygen binary, use that instead
-        if ( QFile(QString::fromAscii("/usr/local/bin/doxygen")).exists() )
-            doxygenPath = QString::fromAscii("/usr/local/bin/");
-        else {
-            qDebug() << tr("Can't find the doxygen command, make sure it's in your $$PATH");
-            doxygenPath = QString::fromAscii("");
-       	}
-   	}
+    if ( !QFile(doxygenPath + QString::fromAscii("doxygen")).exists() ) 
+    {
+      // No doygen binary in the resources, if there is a system doxygen binary, use that instead
+      if ( QFile(QString::fromAscii("/usr/local/bin/doxygen")).exists() )
+      {
+        doxygenPath = QString::fromAscii("/usr/local/bin/");
+      }
+      else 
+      {
+        qDebug() << tr("Can't find the doxygen command, make sure it's in your $$PATH");
+        doxygenPath = QString::fromAscii("");
+      }
+    }
     qDebug() << tr("Getting doxygen from: ") << doxygenPath;
 #endif
 
@@ -416,7 +453,7 @@ void MainWindow::runDoxygen()
     QTextStream t(m_runProcess);
     m_expert->writeConfig(t,false);
     m_runProcess->closeWriteChannel();
-    
+
     if (m_runProcess->state() == QProcess::NotRunning)
     {
       m_outputLog->append(QString::fromAscii("*** Failed to run doxygen\n"));
@@ -485,13 +522,15 @@ void MainWindow::showHtmlOutput()
 {
   QString indexFile = m_expert->getHtmlOutputIndex(m_workingDir->text());
   QFileInfo fi(indexFile);
+  // TODO: the following doesn't seem to work with IE
 #ifdef WIN32
-  QString indexUrl(QString::fromAscii("file:///"));
+  //QString indexUrl(QString::fromAscii("file:///"));
+  ShellExecute(NULL, L"open", fi.absoluteFilePath().utf16(), NULL, NULL, SW_SHOWNORMAL);
 #else
   QString indexUrl(QString::fromAscii("file://"));
-#endif
   indexUrl+=fi.absoluteFilePath();
   QDesktopServices::openUrl(QUrl(indexUrl));
+#endif
 }
 
 void MainWindow::saveLog()
