@@ -16,7 +16,7 @@
   Originally, the script was written in Perl and was known as translator.pl.
   The last Perl version was dated 2002/05/21 (plus some later corrections)
 
-  $Id: translator.py,v 1.79 2007/03/15 10:12:10 dimitri Exp $
+  $Id: translator.py 721 2010-02-16 21:11:17Z dimitri $
   
                                          Petr Prikryl (prikrylp@skil.cz)
                                
@@ -48,8 +48,14 @@
   2005/02/28 - Slight modification to generate "mailto.txt" auxiliary file.
   2005/08/15 - Doxygen's root directory determined primarily from DOXYGEN 
                environment variable. When not found, then relatively to the script.
-  2007/03/20 - The "translate me!" searched in comments and reported if found.             
-  2009/05/09 - Changed HTML output to make it confirm to XHTML DTD
+  2007/03/20 - The "translate me!" searched in comments and reported if found.
+  2008/06/09 - Warning when the MAX_DOT_GRAPH_HEIGHT is still part of trLegendDocs().
+  2009/05/09 - Changed HTML output to fit it with XHTML DTD
+  2009/09/02 - Added percentage info to the report (implemented / to be implemented).
+  2010/02/09 - Added checking/suggestion 'Reimplementation using UTF-8 suggested.
+  2010/03/03 - Added [unreachable] prefix used in maintainers.txt.
+  2010/05/28 - BOM skipped; minor code cleaning.
+  2010/05/31 - e-mail mangled already in maintainers.txt
   """                               
 
 from __future__ import generators
@@ -166,11 +172,12 @@ class Transl:
         self.prototypeDic = {}       # uniPrototype -> prototype
         self.translateMeText = 'translate me!'
         self.translateMeFlag = False # comments with "translate me!" found
+        self.txtMAX_DOT_GRAPH_HEIGHT_flag = False # found in string in trLegendDocs()
         self.obsoleteMethods = None  # list of prototypes to be removed
         self.missingMethods = None   # list of prototypes to be implemented
         self.implementedMethods = None  # list of implemented required methods
         self.adaptMinClass = None    # The newest adapter class that can be used
-            
+        self.isDecodedTranslator = None  # Flag related to internal usage of UTF-8    
         
     def __tokenGenerator(self):
         """Generator that reads the file and yields tokens as 4-tuples.
@@ -220,7 +227,7 @@ class Transl:
 
         # Open the file for reading and extracting tokens until the eof.
         # Initialize the finite automaton.
-        f = file(self.fname)
+        f = open(self.fname)
         lineNo = 0
         line = ''         # init -- see the pos initialization below
         linelen = 0       # init
@@ -239,9 +246,11 @@ class Transl:
             else:
                 lineNo += 1
                 line = f.readline()
+                if line.startswith('\xef\xbb\xbf'):
+                    line = line[3:]    # skip the BOM
                 linelen = len(line)
                 pos = 0
-                if line == '':   # eof
+                if line == '':         # eof
                     status = 777
                 else:
                     c = line[pos]
@@ -769,6 +778,8 @@ class Transl:
         # identifiers.
         prototype = ''    # readable prototype (with everything)
         uniPrototype = '' # unified prototype (without arg. identifiers)
+        warning = ''      # warning message -- if something special detected
+        methodId = None   # processed method id
         
         # Collect the method prototypes. Stop on the closing
         # curly brace followed by the semicolon (end of class).
@@ -823,6 +834,7 @@ class Transl:
                 if tokenId == 'id':
                     prototype += ' ' + tokenStr
                     uniPrototype += ' ' + tokenStr
+                    methodId = tokenStr    # for reporting
                     status = 5
                 else:
                     self.__unexpectedToken(status, tokenId, tokenLineNo)
@@ -884,9 +896,17 @@ class Transl:
                         # Insert new dictionary item.
                         assert(not self.prototypeDic.has_key(uniPrototype))
                         self.prototypeDic[uniPrototype] = prototype
-                        status = 2     # body consumed
+                        status = 2      # body consumed
+                        methodId = None # outside of any method
                 elif tokenId == 'lcurly':
                     curlyCnt += 1
+                    
+                # Warn in special case.     
+                elif methodId == 'trLegendDocs' and tokenId == 'string' \
+                    and tokenStr.find('MAX_DOT_GRAPH_HEIGHT') >= 0:
+                        self.txtMAX_DOT_GRAPH_HEIGHT_flag = True  
+  
+                    
             elif status == 11:   # probably the end of class
                 if tokenId == 'semic':
                     status = 777
@@ -1080,6 +1100,13 @@ class Transl:
             else:
                 self.missingMethods.append(p)
 
+        # Set the least important note first if the translator is decoded.
+        # If yes, then it means that the implementation should be switched
+        # to UTF-8 later (suggestion).
+        self.isDecodedTranslator = self.classId in self.manager.decodedTranslators
+        if self.isDecodedTranslator:
+            self.note = 'Reimplementation using UTF-8 suggested.'
+            
         # Check whether adapter must be used or suggest the newest one.
         # Change the status and set the note accordingly.
         if self.baseClassId != 'Translator':
@@ -1114,10 +1141,17 @@ class Transl:
                     self.adaptMinClass = adaptMinClass
                     self.readableStatus = adaptMinVersion # simplified
         
-        # If everything seems OK, but the explicit mark self.translateMeText 
-        # in comments was found, something must be translated.
-        if not self.note and self.status == '' and self.translateMeFlag:
-            self.note = 'The "%s" found in a comment.' % self.translateMeText
+        # If everything seems OK, some explicit warning flags still could 
+        # be set. 
+        if not self.note and self.status == '' and \
+           (self.translateMeFlag or self.txtMAX_DOT_GRAPH_HEIGHT_flag):
+           self.note = '' 
+           if self.translateMeFlag:
+               self.note += 'The "%s" found in a comment.' % self.translateMeText
+           if self.note != '':
+               self.note += '\n\t\t'          
+           if self.txtMAX_DOT_GRAPH_HEIGHT_flag:
+                self.note += 'The MAX_DOT_GRAPH_HEIGHT found in trLegendDocs()'
         
         # If everything seems OK, but there are obsolete methods, set 
         # the note to clean-up source. This note will be used only when
@@ -1138,18 +1172,21 @@ class Transl:
         # Report the number of not implemented methods.
         fout.write('\n\n\n')
         fout.write(self.classId + '   (' + self.baseClassId + ')')
+        percentImplemented = 100    # init
+        allNum = len(self.manager.requiredMethodsDic) 
         if self.missingMethods:
             num = len(self.missingMethods)
+            percentImplemented = 100 * (allNum - num) / allNum
             fout.write('  %d' % num)
             fout.write(' method')
             if num > 1:
                 fout.write('s')
-            fout.write(' to implement')
+            fout.write(' to implement (%d %%)' % (100 * num / allNum))
         fout.write('\n' + '-' * len(self.classId))
         
         # Write the info about the implemented required methods.
         fout.write('\n\n  Implements %d' % len(self.implementedMethods))
-        fout.write(' of the required methods.')
+        fout.write(' of the required methods (%d %%).' % percentImplemented)
         
         # Report the missing method, but only when it is not English-based
         # translator.
@@ -1253,10 +1290,44 @@ class TrManager:
         self.numLang = None                   # excluding coupled En-based
         self.doxVersion = None                # Doxygen version
         
+        # Capture the knowledge about translators that are not implemented
+        # to use UTF-8 internally.
+        self.decodedTranslators = self.getDecodedTranslators()
+        
         # Build objects where each one is responsible for one translator.
         self.__build()
         
         
+    def getDecodedTranslators(self):
+        """Parses language.cpp to find what translators do not use UTF-8 yet"""
+        decodedTranslators = []
+        
+        # Regular expression to detect the lines like
+        #     theTranslator=new TranslatorDecoder(new TranslatorSwedish);
+        rex = re.compile(r'^\s*theTranslator\s*=\s*new\s+.*$')
+        
+        # Regular expression to get the (optional) TranslatorDecoder and TranslatorXXX
+        rex2 = re.compile(r'\bTranslator\w+')
+        
+        # Parse the lines in the specific source code.
+        f = open(os.path.join(self.src_path, 'language.cpp'), 'rU')
+        for line in f:
+            if rex.match(line):
+                lst = rex2.findall(line)
+                if lst[0] == 'TranslatorDecoder':
+                    decodedTranslators.append(lst[1])
+        f.close()
+        
+        # Display warning when all translator implementations were converted 
+        # to UTF-8.
+        if len(decodedTranslators) == 0:
+            print 'This script should be updated. All translators do use UTF-8'
+            print 'internally.  The TranslatorDecoder adapter should be removed'
+            print 'from the code and its usage should not be checked any more.'
+            
+        return decodedTranslators
+    
+        
     def __build(self):
         """Find the translator files and build the objects for translators."""
         
@@ -1374,7 +1445,7 @@ class TrManager:
                     self.numLang -= 1    # the couple will be counted as one
         
         # Extract the version of Doxygen.
-        f = file(os.path.join(self.doxy_path, 'VERSION'))
+        f = open(os.path.join(self.doxy_path, 'VERSION'))
         self.doxVersion = f.readline().strip()
         f.close()
         
@@ -1422,7 +1493,7 @@ class TrManager:
         
         # Read content of the file as one string.
         assert os.path.isfile(fname)
-        f = file(fname)
+        f = open(fname)
         cont = f.read()
         f.close()
         
@@ -1460,11 +1531,19 @@ class TrManager:
         return trdic
         
         
-    
+    def __emails(self, classId):
+        """Returns the list of maintainer emails.
         
-    def __email(self, classId):
-        """Returns the first maintainer for the translator class"""
-        return self.__maintainersDic[classId][0][1]
+        The method returns the list of e-mail adresses for the translator
+        class, but only the addresses that were not marked as [unreachable]."""
+        lst = []
+        for m in self.__maintainersDic[classId]:
+            if not m[1].startswith('[unreachable]'):
+                email = m[1]
+                email = email.replace(' at ', '@') # Unmangle the mangled e-mail 
+                email = email.replace(' dot ', '.')
+                lst.append(email)
+        return lst
                     
     
     def generateTranslatorReport(self):
@@ -1473,7 +1552,7 @@ class TrManager:
         output = os.path.join(self.doc_path, self.translatorReportFileName)
         
         # Open the textual report file for the output.
-        f = file(output, 'w')
+        f = open(output, 'w')
 
         # Output the information about the version.
         f.write('(' + self.doxVersion + ')\n\n')
@@ -1501,7 +1580,7 @@ class TrManager:
         # The e-mail addresses of the maintainers will be collected to 
         # the auxiliary file in the order of translator classes listed
         # in the translator report.
-        fmail = file('mailto.txt', 'w')
+        fmail = open('mailto.txt', 'w')
         
         # Write the list of up-to-date translator classes. 
         if self.upToDateIdLst:
@@ -1521,7 +1600,7 @@ class TrManager:
                 if obj.note:
                     f.write(' -- ' + obj.note)
                 f.write('\n')
-                mailtoLst.append(self.__email(obj.classId))
+                mailtoLst.extend(self.__emails(obj.classId))
                 
             fmail.write('up-to-date\n')
             fmail.write('; '.join(mailtoLst))
@@ -1541,6 +1620,7 @@ class TrManager:
             adaptMinVersion = '9.9.99'
             
             mailtoLst = []
+            numRequired = len(self.requiredMethodsDic)
             for x in self.adaptIdLst:
                 obj = self.__translDic[x]
                 f.write('  %-30s' % obj.classId)
@@ -1548,11 +1628,13 @@ class TrManager:
                 numimpl = len(obj.missingMethods)
                 pluralS = ''
                 if numimpl > 1: pluralS = 's'
-                f.write('\t%2d method%s to implement' % (numimpl, pluralS))
+                percent = 100 * numimpl / numRequired
+                f.write('\t%2d method%s to implement (%d %%)' % (
+                        numimpl, pluralS, percent))
                 if obj.note:
                     f.write('\n\tNote: ' + obj.note + '\n')
                 f.write('\n')
-                mailtoLst.append(self.__email(obj.classId)) # to maintainer
+                mailtoLst.extend(self.__emails(obj.classId)) # to maintainer
                 
                 # Check the level of required adapter classes.
                 if obj.status != '0.0.00' and obj.status < adaptMinVersion:
@@ -1655,7 +1737,7 @@ class TrManager:
             self.lastModificationTime = tim
         
         # Process the content of the maintainers file.
-        f = file(fname)
+        f = open(fname)
         inside = False  # inside the record for the language
         lineReady = True
         classId = None
@@ -1685,7 +1767,8 @@ class TrManager:
                         self.__maintainersDic[classId] = []
                     
                     # Split the information about the maintainer and append
-                    # the tuple.
+                    # the tuple. The address may be prefixed '[unreachable]'.
+                    # This will be processed later.
                     lst = line.split(':', 1)
                     assert(len(lst) == 2)
                     t = (lst[0].strip(), lst[1].strip())
@@ -1718,7 +1801,7 @@ class TrManager:
         #
         # Read the template of the documentation, and remove the first
         # attention lines.
-        f = file(fTplName)
+        f = open(fTplName)
         line = f.readline()
         while line[0] != '/':
             line = f.readline()
@@ -1794,20 +1877,17 @@ class TrManager:
             if not mm and self.__maintainersDic.has_key(obj.classId):
                 lm = [ m[0] for m in self.__maintainersDic[obj.classId] ]  
                 mm = '<br/>'.join(lm)
-                le = [ m[1] for m in self.__maintainersDic[obj.classId] ]
+                
+                # Unreachable adresses will not be displayed at all.
+                le = []
+                for m in self.__maintainersDic[obj.classId]:
+                    address = m[1]
+                    if address.startswith('[unreachable]'):
+                        address = '[unreachable]'
+                    le.append(address)    
                 ee = '<br/>'.join(le)
             
-            # Mangle the e-mail and replace the entity references.
-            if ee and ee != '&nbsp;':
-                # More than one maintainer address separated by <br> can be used.
-                emails = ee.split('<br/>')
-                mangled_list = []
-                for email in emails:
-                    name, domain = email.split('@')
-                    domain = domain.replace('.', ' dot ')
-                    mangled_list.append(name + ' at ' + domain)
-                ee = '<br/>'.join(mangled_list)
-                
+            # Replace the entity references.    
             if mm:
                 mm = mm.replace('&ccaron;', '&#x010d;')
                 mm = mm.replace('&rcaron;', '&#x0159;')
@@ -1830,13 +1910,15 @@ class TrManager:
         # Define templates for LaTeX table parts of the documentation.
         latexTableTpl = r'''
             \latexonly
-            \begin{tabular}{|l|l|l|l|}
+            \footnotesize
+            \begin{longtable}{|l|l|l|l|}
               \hline 
               {\bf Language} & {\bf Maintainer} & {\bf Contact address} & {\bf Status} \\
               \hline
             %s
               \hline
-            \end{tabular}
+            \end{longtable}
+            \normalsize
             \endlatexonly
             '''
         latexTableTpl = dedent(latexTableTpl)    
@@ -1905,7 +1987,7 @@ class TrManager:
         tplDic['informationTable'] = htmlTable + '\n' + latexTable 
 
         # Insert the symbols into the document template and write it down.
-        f = file(fDocName, 'w')
+        f = open(fDocName, 'w')
         f.write(doctpl % tplDic)
         f.close()
                     
