@@ -2,7 +2,7 @@
  *
  * $Id: index.cpp,v 1.30 1999/03/06 22:15:39 root Exp $
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -198,9 +198,10 @@ static bool matchExcludedSymbols(const char *name)
 
 void Definition::addToMap(const char *name,Definition *d)
 {
+  bool vhdlOpt = Config_getBool("OPTIMIZE_OUTPUT_VHDL");
   QCString symbolName = name;
   int index=computeQualifiedIndex(symbolName);
-  if (index!=-1) symbolName=symbolName.mid(index+2);
+  if (!vhdlOpt && index!=-1) symbolName=symbolName.mid(index+2);
   if (!symbolName.isEmpty()) 
   {
     //printf("******* adding symbol `%s' (%p)\n",symbolName.data(),d);
@@ -244,9 +245,7 @@ void Definition::addToMap(const char *name,Definition *d)
 
 void Definition::removeFromMap(Definition *d)
 {
-  QCString symbolName = d->symbolName();
-  int index=computeQualifiedIndex(symbolName);
-  if (index!=-1) symbolName=symbolName.mid(index+2);
+  QString symbolName = d->m_symbolName;
   if (!symbolName.isEmpty()) 
   {
     //printf("******* removing symbol `%s' (%p)\n",symbolName.data(),d);
@@ -382,8 +381,8 @@ bool Definition::_docsAlreadyAdded(const QCString &doc)
 }
 
 void Definition::_setDocumentation(const char *d,const char *docFile,int docLine,
-                                   bool stripWhiteSpace,bool atTop) 
-{ 
+                                   bool stripWhiteSpace,bool atTop)
+{
   if (d==0) return;
   //printf("Definition::setDocumentation(%s,%s,%d,%d)\n",d,docFile,docLine,stripWhiteSpace);
   QCString doc = d;
@@ -404,21 +403,26 @@ void Definition::_setDocumentation(const char *d,const char *docFile,int docLine
     }
     if (m_impl->details->doc.isEmpty()) // fresh detailed description
     {
-      m_impl->details->doc  = doc;
+      m_impl->details->doc = doc;
     }
     else if (atTop) // another detailed description, append it to the start
     {
-      m_impl->details->doc  = doc+"\n\n"+m_impl->details->doc;
+      m_impl->details->doc = doc+"\n\n"+m_impl->details->doc;
     }
     else // another detailed description, append it to the end
     {
-      m_impl->details->doc  += "\n\n"+doc;
+      m_impl->details->doc += "\n\n"+doc;
     }
     if (docLine!=-1) // store location if valid
     {
       m_impl->details->file = docFile;
       m_impl->details->line = docLine;
     }
+    else
+    {
+      m_impl->details->file = docFile;
+      m_impl->details->line = 1;
+    }
   }
 }
 
@@ -445,7 +449,7 @@ void Definition::_setBriefDescription(const char *b,const char *briefFile,int br
   {
     switch(brief.at(bl-1))
     {
-      case '.': case '!': case '?': break;
+      case '.': case '!': case '?': case '>': case ':': break;
       default: 
         if (uni_isupper(brief.at(0))) brief+='.'; 
         break;
@@ -528,7 +532,7 @@ static bool readCodeFragment(const char *fileName,
   bool usePipe = !filter.isEmpty() && filterSourceFiles;
   if (!usePipe) // no filter given or wanted
   {
-    f = fopen(fileName,"r");
+    f = portable_fopen(fileName,"r");
   }
   else // use filter
   {
@@ -594,7 +598,11 @@ static bool readCodeFragment(const char *fileName,
         }
         // copy until end of line
         result+=c;
-        if (c==':') result+=cn;
+        if (c==':') 
+        {
+          result+=cn;
+          if (cn=='\n') lineNr++;
+        }
         startLine=lineNr;
         const int maxLineLength=4096;
         char lineStr[maxLineLength];
@@ -611,9 +619,10 @@ static bool readCodeFragment(const char *fileName,
             {
               size_read=qstrlen(p); 
             }
-            else 
+            else  // nothing read
             {
               size_read=-1;
+              lineStr[0]='\0';
             }
             result+=lineStr;
           } while (size_read == (maxLineLength-1));
@@ -773,7 +782,7 @@ void Definition::writeSourceDef(OutputList &ol,const char *)
     }
     else
     {
-      err("Error: translation error: invalid markers in trDefinedInSourceFile()\n");
+      err("error: translation error: invalid markers in trDefinedInSourceFile()\n");
     }
   }
   ol.popGeneratorState();
@@ -830,7 +839,8 @@ void Definition::writeInlineCode(OutputList &ol,const char *scopeName)
                        actualStart,      // startLine
                        actualEnd,        // endLine
                        TRUE,             // inlineFragment
-                       thisMd            // memberDef
+                       thisMd,           // memberDef
+                       FALSE             // show line numbers
                       );
       ol.endCodeFragment();
       ol.endParagraph();
@@ -845,9 +855,11 @@ void Definition::writeInlineCode(OutputList &ol,const char *scopeName)
 void Definition::_writeSourceRefList(OutputList &ol,const char *scopeName,
     const QCString &text,MemberSDict *members,bool /*funcOnly*/)
 {
-static bool latexSourceCode = Config_getBool("LATEX_SOURCE_CODE"); 
- ol.pushGeneratorState();
-  if (/*Config_getBool("SOURCE_BROWSER") &&*/ members)
+  static bool latexSourceCode = Config_getBool("LATEX_SOURCE_CODE"); 
+  static bool sourceBrowser   = Config_getBool("SOURCE_BROWSER");
+  static bool refLinkSource   = Config_getBool("REFERENCES_LINK_SOURCE");
+  ol.pushGeneratorState();
+  if (members)
   {
     ol.startParagraph();
     ol.parseText(text);
@@ -884,22 +896,29 @@ static bool latexSourceCode = Config_getBool("LATEX_SOURCE_CODE");
             (md->isFunction() || md->isSlot() || 
              md->isPrototype() || md->isSignal()
             )
-           ) name+="()";
+           ) 
+        {
+          name+="()";
+        }
         //Definition *d = md->getOutputFileBase();
         //if (d==Doxygen::globalScope) d=md->getBodyDef();
-        if (!(md->isLinkable() && !Config_getBool("REFERENCES_LINK_SOURCE")) && md->getStartBodyLine()!=-1 && md->getBodyDef()) 
+        if (sourceBrowser &&
+            !(md->isLinkable() && !refLinkSource) && 
+            md->getStartBodyLine()!=-1 && 
+            md->getBodyDef()
+           )
         {
           //printf("md->getBodyDef()=%p global=%p\n",md->getBodyDef(),Doxygen::globalScope); 
           // for HTML write a real link
           ol.pushGeneratorState();
           //ol.disableAllBut(OutputGenerator::Html);
-           
-         ol.disable(OutputGenerator::RTF); 
-         ol.disable(OutputGenerator::Man); 
-         if (!latexSourceCode)
-         {
-          ol.disable(OutputGenerator::Latex);
-        }
+
+          ol.disable(OutputGenerator::RTF); 
+          ol.disable(OutputGenerator::Man); 
+          if (!latexSourceCode)
+          {
+            ol.disable(OutputGenerator::Latex);
+          }
           QCString lineStr,anchorStr;
           anchorStr.sprintf("l%05d",md->getStartBodyLine());
           //printf("Write object link to %s\n",md->getBodyDef()->getSourceFileBase().data());
@@ -908,11 +927,11 @@ static bool latexSourceCode = Config_getBool("LATEX_SOURCE_CODE");
 
           // for the other output formats just mention the name
           ol.pushGeneratorState();
-           ol.disable(OutputGenerator::Html);
-           if (latexSourceCode)
+          ol.disable(OutputGenerator::Html);
+          if (latexSourceCode)
           {
             ol.disable(OutputGenerator::Latex);
-           }
+          }
           ol.docify(name);
           ol.popGeneratorState();
         }
@@ -926,20 +945,20 @@ static bool latexSourceCode = Config_getBool("LATEX_SOURCE_CODE");
           if (!latexSourceCode)
           {
             ol.disable(OutputGenerator::Latex);
-           }
-     
+          }
+
           ol.writeObjectLink(md->getReference(),
-                             md->getOutputFileBase(),
-                             md->anchor(),name);
+              md->getOutputFileBase(),
+              md->anchor(),name);
           ol.popGeneratorState();
 
           // for the other output formats just mention the name
           ol.pushGeneratorState();
           ol.disable(OutputGenerator::Html);
-           if (latexSourceCode)
-           {
+          if (latexSourceCode)
+          {
             ol.disable(OutputGenerator::Latex);
-           }
+          }
           ol.docify(name);
           ol.popGeneratorState();
         }
@@ -1056,7 +1075,7 @@ Definition *Definition::findInnerCompound(const char *)
 
 void Definition::addInnerCompound(Definition *)
 {
-  err("Error: Definition::addInnerCompound() called\n");
+  err("error: Definition::addInnerCompound() called\n");
 }
 
 QCString Definition::qualifiedName() const
@@ -1137,6 +1156,7 @@ void Definition::makePartOfGroup(GroupDef *gd)
 
 void Definition::setRefItems(const QList<ListItemInfo> *sli)
 {
+  //printf("%s::setRefItems()\n",name().data());
   if (sli)
   {
     makeResident();
@@ -1157,6 +1177,7 @@ void Definition::setRefItems(const QList<ListItemInfo> *sli)
 
 void Definition::mergeRefItems(Definition *d)
 {
+  //printf("%s::mergeRefItems()\n",name().data());
   LockingPtr< QList<ListItemInfo> > xrefList = d->xrefListItems();
   if (xrefList!=0)
   {
@@ -1217,33 +1238,45 @@ QCString Definition::convertNameToFile(const char *name,bool allowDots) const
   }
 }
 
+QCString Definition::pathFragment() const
+{
+  makeResident();
+  QCString result;
+  if (m_impl->outerScope && m_impl->outerScope!=Doxygen::globalScope)
+  {
+    result = m_impl->outerScope->pathFragment();
+  }
+  if (isLinkable())
+  {
+    if (!result.isEmpty()) result+="/";
+    if (definitionType()==Definition::TypeGroup && ((const GroupDef*)this)->groupTitle())
+    {
+      result+=((const GroupDef*)this)->groupTitle();
+    }
+    else if (definitionType()==Definition::TypePage && !((const PageDef*)this)->title().isEmpty())
+    {
+      result+=((const PageDef*)this)->title();
+    }
+    else
+    {
+      result+=m_impl->localName;
+    }
+  }
+  else
+  {
+    result+=m_impl->localName;
+  }
+  return result;
+}
+
 void Definition::writePathFragment(OutputList &ol) const
 {
   makeResident();
   if (m_impl->outerScope && m_impl->outerScope!=Doxygen::globalScope)
   {
     m_impl->outerScope->writePathFragment(ol);
-    if (m_impl->outerScope->definitionType()==Definition::TypeClass ||
-        m_impl->outerScope->definitionType()==Definition::TypeNamespace)
-    {
-      if (Config_getBool("OPTIMIZE_OUTPUT_JAVA") ||
-          Config_getBool("OPTIMIZE_OUTPUT_VHDL")
-         )
-      {
-        ol.writeString(".");
-      }
-      else
-      {
-        ol.writeString("::");
-      }
-    }
-    else
-    {
-      ol.writeString("&nbsp;");
-      ol.writeString("&raquo");
-      ol.writeString("&nbsp;");
-    }
   }
+  ol.writeString("      <li>");
   if (isLinkable())
   {
     if (definitionType()==Definition::TypeGroup && ((const GroupDef*)this)->groupTitle())
@@ -1254,6 +1287,10 @@ void Definition::writePathFragment(OutputList &ol) const
     {
       ol.writeObjectLink(getReference(),getOutputFileBase(),0,((const PageDef*)this)->title());
     }
+    else if (definitionType()==Definition::TypeClass)
+    {
+      ol.writeObjectLink(getReference(),getOutputFileBase(),0,((const ClassDef*)this)->displayName());
+    }
     else
     {
       ol.writeObjectLink(getReference(),getOutputFileBase(),0,m_impl->localName);
@@ -1265,6 +1302,7 @@ void Definition::writePathFragment(OutputList &ol) const
     ol.docify(m_impl->localName);
     ol.endBold();
   }
+  ol.writeString("      </li>\n");
 }
 
 void Definition::writeNavigationPath(OutputList &ol) const
@@ -1272,9 +1310,11 @@ void Definition::writeNavigationPath(OutputList &ol) const
   ol.pushGeneratorState();
   ol.disableAllBut(OutputGenerator::Html);
 
-  ol.writeString("  <div class=\"navpath\">");
+  ol.writeString("  <div class=\"navpath\">\n");
+  ol.writeString("    <ul>\n");
   writePathFragment(ol);
-  ol.writeString("\n  </div>\n");
+  ol.writeString("    </ul>\n");
+  ol.writeString("  </div>\n");
 
   ol.popGeneratorState();
 }
