@@ -3,7 +3,7 @@
  * $Id: diagram.cpp,v 1.30 2001/03/19 19:27:40 root Exp $
  *
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -21,7 +21,7 @@
 #include <stdlib.h>
 #include <qlist.h>
 #include <qarray.h>
-#include <qtextstream.h>
+#include "ftextstream.h"
 #include <qfile.h>
 
 #include "diagram.h"
@@ -142,7 +142,7 @@ static void writeBitmapBox(DiagramItem *di,Image *image,
   }
 }
 
-static void writeVectorBox(QTextStream &t,DiagramItem *di,
+static void writeVectorBox(FTextStream &t,DiagramItem *di,
                            float x,float y,bool children=FALSE)
 {
   if (di->virtualness()==Virtual) t << "dashed\n";
@@ -151,29 +151,19 @@ static void writeVectorBox(QTextStream &t,DiagramItem *di,
   if (di->virtualness()==Virtual) t << "solid\n";
 }
 
-static void writeMapArea(QTextStream &t,ClassDef *cd,QCString relPath,
+static void writeMapArea(FTextStream &t,ClassDef *cd,QCString relPath,
                          int x,int y,int w,int h)
 {
   if (cd->isLinkable())
   {
-    QCString *dest;
     QCString ref=cd->getReference();
     t << "<area ";
     if (!ref.isEmpty()) 
     {
-      t << "doxygen=\"" << ref << ":";
-      if ((dest=Doxygen::tagDestinationDict[ref])) t << *dest << "/";
-      t << "\" ";
+      t << externalLinkTarget() << externalRef(relPath,ref,FALSE);
     }
     t << "href=\"";
-    if (!ref.isEmpty())
-    {
-      if ((dest=Doxygen::tagDestinationDict[ref])) t << *dest << "/";
-    }
-    else
-    {
-      t << relPath;
-    }
+    t << externalRef(relPath,ref,TRUE);
     t << cd->getOutputFileBase() << Doxygen::htmlFileExtension << "\" ";
     t << "alt=\"" << convertToXML(cd->displayName()); 
     t << "\" shape=\"rect\" coords=\"" << x << "," << y << ",";
@@ -485,7 +475,7 @@ void TreeDiagram::computeExtremes(uint *maxLabelLen,uint *maxXPos)
   if (maxXPos)     *maxXPos=mx;
 }
 
-void TreeDiagram::drawBoxes(QTextStream &t,Image *image, 
+void TreeDiagram::drawBoxes(FTextStream &t,Image *image, 
                             bool doBase,bool bitmap,
                             uint baseRows,uint superRows,
                             uint cellWidth,uint cellHeight,
@@ -616,7 +606,7 @@ void TreeDiagram::drawBoxes(QTextStream &t,Image *image,
   }
 }
 
-void TreeDiagram::drawConnectors(QTextStream &t,Image *image,
+void TreeDiagram::drawConnectors(FTextStream &t,Image *image,
                                  bool doBase,bool bitmap,
                                  uint baseRows,uint superRows,
                                  uint cellWidth,uint cellHeight)
@@ -968,7 +958,7 @@ ClassDiagram::~ClassDiagram()
   delete super;
 }
 
-void ClassDiagram::writeFigure(QTextStream &output,const char *path,
+void ClassDiagram::writeFigure(FTextStream &output,const char *path,
                                const char *fileName) const
 {
   uint baseRows=base->computeRows();
@@ -999,7 +989,7 @@ void ClassDiagram::writeFigure(QTextStream &output,const char *path,
   }
 
   //output << "}\n";
-  output << ":\\begin{figure}[H]\n"
+  output << "\\begin{figure}[H]\n"
             "\\begin{center}\n"
             "\\leavevmode\n";
   output << "\\includegraphics[height=" << realHeight << "cm]{" 
@@ -1018,7 +1008,7 @@ void ClassDiagram::writeFigure(QTextStream &output,const char *path,
     err("Could not open file %s for writing\n",convertToQCString(f1.name()).data());
     exit(1);
   }
-  QTextStream t(&f1);
+  FTextStream t(&f1);
   
   //printf("writeEPS() rows=%d cols=%d\n",rows,cols);
   
@@ -1253,16 +1243,19 @@ void ClassDiagram::writeFigure(QTextStream &output,const char *path,
     epstopdfArgs.sprintf("\"%s.eps\" --outfile=\"%s.pdf\"",
                    epsBaseName.data(),epsBaseName.data());
     //printf("Converting eps using `%s'\n",epstopdfCmd.data());
+    portable_sysTimerStart();
     if (portable_system("epstopdf",epstopdfArgs)!=0)
     {
-       err("Error: Problems running epstopdf. Check your TeX installation!\n");
+       err("error: Problems running epstopdf. Check your TeX installation!\n");
+       portable_sysTimerStop();
        return;
     }
+    portable_sysTimerStop();
   }
 }
 
 
-void ClassDiagram::writeImage(QTextStream &t,const char *path,
+void ClassDiagram::writeImage(FTextStream &t,const char *path,
                               const char *relPath,const char *fileName, 
                               bool generateMap) const
 {
@@ -1289,7 +1282,7 @@ void ClassDiagram::writeImage(QTextStream &t,const char *path,
   base->drawConnectors(t,&image,TRUE,TRUE,baseRows,superRows,cellWidth,cellHeight);
   super->drawConnectors(t,&image,FALSE,TRUE,baseRows,superRows,cellWidth,cellHeight);
 
-#define IMAGE_EXT ".gif"
+#define IMAGE_EXT ".png"
   image.save((QCString)path+"/"+fileName+IMAGE_EXT);
   Doxygen::indexList.addImageFile(QCString(fileName)+IMAGE_EXT);
   
