@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -44,6 +44,10 @@ void DocSets::initialize()
   if (bundleId.isEmpty()) bundleId="org.doxygen.Project";
   QCString feedName = Config_getString("DOCSET_FEEDNAME");
   if (feedName.isEmpty()) feedName="FeedName";
+  QCString publisherId = Config_getString("DOCSET_PUBLISHER_ID");
+  if (publisherId.isEmpty()) publisherId="PublisherId";
+  QCString publisherName = Config_getString("DOCSET_PUBLISHER_NAME");
+  if (publisherName.isEmpty()) publisherName="PublisherName";
 
   // -- write Makefile
   {
@@ -54,14 +58,13 @@ void DocSets::initialize()
     err("Could not open file %s for writing\n",mfName.data());
     exit(1);
   }
-  QTextStream ts(&makefile);
-  ts.setEncoding(QTextStream::UnicodeUTF8);
+  FTextStream ts(&makefile);
 
   ts << "DOCSET_NAME=" << bundleId << ".docset\n" 
         "DOCSET_CONTENTS=$(DOCSET_NAME)/Contents\n"
         "DOCSET_RESOURCES=$(DOCSET_CONTENTS)/Resources\n"
         "DOCSET_DOCUMENTS=$(DOCSET_RESOURCES)/Documents\n"
-        "DOCSET_INSTALL=~/Library/Developer/Shared/Documentation/DocSets\n"
+        "DESTDIR=~/Library/Developer/Shared/Documentation/DocSets\n"
         "XCODE_INSTALL=$(shell xcode-select -print-path)\n"
         "\n"
         "all: docset\n"
@@ -85,11 +88,11 @@ void DocSets::initialize()
         "\trm -f $(DOCSET_RESOURCES)/Tokens.xml\n"
         "\n"
         "install: docset\n"
-        "\tmkdir -p $(DOCSET_INSTALL)\n"
-        "\tcp -R $(DOCSET_NAME) $(DOCSET_INSTALL)\n"
+        "\tmkdir -p $(DESTDIR)\n"
+        "\tcp -R $(DOCSET_NAME) $(DESTDIR)\n"
         "\n"
         "uninstall:\n"
-        "\trm -rf $(DOCSET_INSTALL)\n"
+        "\trm -rf $(DESTDIR)/$(DOCSET_NAME)\n"
         "\n"
         "always:\n";
   }
@@ -103,8 +106,7 @@ void DocSets::initialize()
     err("Could not open file %s for writing\n",plName.data());
     exit(1);
   }
-  QTextStream ts(&plist);
-  ts.setEncoding(QTextStream::UnicodeUTF8);
+  FTextStream ts(&plist);
 
   ts << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n" 
         "<!DOCTYPE plist PUBLIC \"-//Apple Computer//DTD PLIST 1.0//EN\"\n" 
@@ -117,6 +119,10 @@ void DocSets::initialize()
         "     <string>" << bundleId << ".docset</string>\n" 
         "     <key>DocSetFeedName</key>\n" 
         "     <string>" << feedName << "</string>\n"
+        "     <key>DocSetPublisherIdentifier</key>\n"
+        "     <string>" << publisherId << "</string>\n"
+        "     <key>DocSetPublisherName</key>\n"
+        "     <string>" << publisherName << "</string>\n"
         "</dict>\n"
         "</plist>\n";
   }
@@ -131,7 +137,6 @@ void DocSets::initialize()
   }
   QCString indexName=Config_getBool("GENERATE_TREEVIEW")?"main":"index";
   m_nts.setDevice(m_nf);
-  m_nts.setEncoding(QTextStream::UnicodeUTF8);
   m_nts << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" << endl;
   m_nts << "<DocSetNodes version=\"1.0\">" << endl;
   m_nts << "  <TOC>" << endl;
@@ -151,7 +156,6 @@ void DocSets::initialize()
     exit(1);
   }
   m_tts.setDevice(m_tf);
-  m_tts.setEncoding(QTextStream::UnicodeUTF8);
   m_tts << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" << endl;
   m_tts << "<Tokens version=\"1.0\">" << endl;
 }
@@ -218,24 +222,36 @@ void DocSets::addContentsItem(bool isDir,
     m_firstNode.at(m_dc-1)=FALSE;
     m_nts << indent() << " <Node>" << endl;
     m_nts << indent() << "  <Name>" << convertToXML(name) << "</Name>" << endl;
-    m_nts << indent() << "  <Path>" << file << Doxygen::htmlFileExtension;
+    m_nts << indent() << "  <Path>" << file << Doxygen::htmlFileExtension << "</Path>" << endl;
     if (anchor)
     {
-      m_nts << "#" << anchor;
+      m_nts << indent() << "  <Anchor>" << anchor << "</Anchor>" << endl;
     }
-    m_nts << "</Path>" << endl;
   }
 }
 
-void DocSets::addIndexItem(const char *, const char *, 
-                           const char *, const char *,
-                           const char *,const MemberDef *md)
+void DocSets::addIndexItem(Definition *context,MemberDef *md,
+                           const char *anchor,const char *word)
 {
-  if (!md->isLinkable()) return; // internal symbol
+  (void)anchor;
+  (void)word;
+  if (md==0 || context==0) return; // TODO: also index non members...
 
-  ClassDef *cd     = md->getClassDef();
-  NamespaceDef *nd = md->getNamespaceDef();
-  FileDef  *fd     = md->getFileDef();
+  FileDef *fd      = 0;
+  ClassDef *cd     = 0;
+  NamespaceDef *nd = 0;
+
+  if (md)
+  {
+    fd = md->getFileDef();
+    cd = md->getClassDef();
+    nd = md->getNamespaceDef();
+    if (!md->isLinkable()) return; // internal symbol
+  }
+
+  QCString scope;
+  QCString type;
+  QCString decl;
 
   // determine language
   QCString lang;
@@ -246,132 +262,158 @@ void DocSets::addIndexItem(const char *, const char *,
     case SrcLangExt_Cpp:
     case SrcLangExt_ObjC:
       {
-        if (md->isObjCMethod() || md->isObjCProperty())
+        if (md && (md->isObjCMethod() || md->isObjCProperty()))
           lang="occ";  // Objective C/C++
         else if (fd && fd->name().right(2).lower()==".c") 
           lang="c";    // Plain C
         else if (cd==0 && nd==0)
           lang="c";    // Plain C symbol outside any class or namespace
-        else                                      
+        else
           lang="cpp";  // C++
       }
       break;
-    case SrcLangExt_IDL:    lang="idl"; break;        // IDL
-    case SrcLangExt_CSharp: lang="csharp"; break;     // C#
-    case SrcLangExt_PHP:    lang="php"; break;        // PHP4/5
-    case SrcLangExt_D:      lang="d"; break;          // D
-    case SrcLangExt_Java:   lang="java"; break;       // Java
-    case SrcLangExt_JS:     lang="javascript"; break; // Javascript
-    case SrcLangExt_Python: lang="python"; break;     // Python
-    case SrcLangExt_F90:    lang="fortran"; break;    // Fortran
-    case SrcLangExt_VHDL:   lang="vhdl"; break;       // VHDL
-    case SrcLangExt_XML:    lang="xml"; break;        // DBUS XML
+    case SrcLangExt_IDL:     lang="idl"; break;        // IDL
+    case SrcLangExt_CSharp:  lang="csharp"; break;     // C#
+    case SrcLangExt_PHP:     lang="php"; break;        // PHP4/5
+    case SrcLangExt_D:       lang="d"; break;          // D
+    case SrcLangExt_Java:    lang="java"; break;       // Java
+    case SrcLangExt_JS:      lang="javascript"; break; // Javascript
+    case SrcLangExt_Python:  lang="python"; break;     // Python
+    case SrcLangExt_F90:     lang="fortran"; break;    // Fortran
+    case SrcLangExt_VHDL:    lang="vhdl"; break;       // VHDL
+    case SrcLangExt_XML:     lang="xml"; break;        // DBUS XML
+    case SrcLangExt_Unknown: lang="unknown"; break;   // should not happen!
   }
 
-  // determine scope
-  QCString scope;
-  QCString type;
-  QCString decl;
-  Definition *d = 0;
-  if (fd && fd->isLinkable() && m_scopes.find(fd->getOutputFileBase())==0)
+  if (md)
   {
-    writeToken(m_tts,fd,"file",lang,0,0,0);
-    m_scopes.append(fd->getOutputFileBase(),(void*)0x8);
-  }
-  if (cd) 
-  {
-    scope = cd->qualifiedName();
-    if (cd->isTemplate()) 
-      type="tmplt";
-    else if (cd->compoundType()==ClassDef::Protocol) 
+    if (context==0)
     {
-      type="intf";
-      if (scope.right(2)=="-p") scope=scope.left(scope.length()-2);
+      if (md->getGroupDef())
+        context = md->getGroupDef();
+      else if (md->getFileDef())
+        context = md->getFileDef();
     }
-    else if (cd->compoundType()==ClassDef::Interface) 
-      type="cl";
-    else if (cd->compoundType()==ClassDef::Category)
-      type="cat";
-    else 
-      type = "cl";
-    d = cd;
-    IncludeInfo *ii = cd->includeInfo();
-    if (ii)
-    {
-      decl=ii->includeName;
-      if (decl.isEmpty())
-      {
-        decl=ii->local;
-      }
-    }
-  }
-  else if (nd) 
-  {
-    scope = nd->name();
-    type = "ns";
-    d = cd;
-  }
-  if (d && d->isLinkable() && m_scopes.find(d->getOutputFileBase())==0)
-  {
-    writeToken(m_tts,d,type,lang,0,0,decl);
-    m_scopes.append(d->getOutputFileBase(),(void*)0x8);
-  }
+    if (context==0) return; // should not happen
 
-  switch (md->memberType())
-  {
-    case MemberDef::Define:
-      type="macro"; break;
-    case MemberDef::Function:
-      if (cd && (cd->compoundType()==ClassDef::Interface || 
-                 cd->compoundType()==ClassDef::Class)
-         ) 
-      {
-        if (md->isStatic())
-          type="clm";
+    switch (md->memberType())
+    {
+      case MemberDef::Define:
+        type="macro"; break;
+      case MemberDef::Function:
+        if (cd && (cd->compoundType()==ClassDef::Interface ||
+              cd->compoundType()==ClassDef::Class))
+        {
+          if (md->isStatic())
+            type="clm";         // class member
+          else
+            type="instm";       // instance member
+        }
+        else if (cd && cd->compoundType()==ClassDef::Protocol)
+        {
+          if (md->isStatic())
+            type="intfcm";     // interface class member
+          else
+            type="intfm";      // interface member
+        }
         else
-          type="instm";
+          type="func";
+        break;
+      case MemberDef::Variable:
+        type="data"; break;
+      case MemberDef::Typedef:
+        type="tdef"; break;
+      case MemberDef::Enumeration:
+        type="enum"; break;
+      case MemberDef::EnumValue:
+        type="econst"; break;
+        //case MemberDef::Prototype:
+        //  type="prototype"; break;
+      case MemberDef::Signal:
+        type="signal"; break;
+      case MemberDef::Slot:
+        type="slot"; break;
+      case MemberDef::Friend:
+        type="ffunc"; break;
+      case MemberDef::DCOP:
+        type="dcop"; break;
+      case MemberDef::Property:
+        if (cd && cd->compoundType()==ClassDef::Protocol) 
+          type="intfp";         // interface property
+        else 
+          type="instp";         // instance property
+        break;
+      case MemberDef::Event:
+        type="event"; break;
+    }
+    writeToken(m_tts,md,type,lang,scope,md->anchor());
+  }
+  else if (context && context->isLinkable())
+  {
+    if (fd==0 && context->definitionType()==Definition::TypeFile)
+    {
+      fd = (FileDef*)context;
+    }
+    if (cd==0 && context->definitionType()==Definition::TypeClass)
+    {
+      cd = (ClassDef*)context;
+    }
+    if (nd==0 && context->definitionType()==Definition::TypeNamespace)
+    {
+      nd = (NamespaceDef*)context;
+    }
+    if (fd)
+    {
+      type="file";
+    }
+    else if (cd) 
+    {
+      scope = cd->qualifiedName();
+      if (cd->isTemplate())
+      {
+        type="tmplt";
+      }
+      else if (cd->compoundType()==ClassDef::Protocol) 
+      {
+        type="intf";
+        if (scope.right(2)=="-p") scope=scope.left(scope.length()-2);
+      }
+      else if (cd->compoundType()==ClassDef::Interface)
+      {
+        type="cl";
       }
-      else if (cd && cd->compoundType()==ClassDef::Protocol) 
+      else if (cd->compoundType()==ClassDef::Category)
       {
-        if (md->isStatic())
-          type="intfcm";
-        else
-          type="intfm";
+        type="cat";
       }
       else 
-        type="func"; 
-      break;
-    case MemberDef::Variable:
-      type="data"; break;
-    case MemberDef::Typedef:
-      type="tdef"; break;
-    case MemberDef::Enumeration:
-      type="enum"; break;
-    case MemberDef::EnumValue:
-      type="econst"; break;
-    //case MemberDef::Prototype:
-    //  type="prototype"; break;
-    case MemberDef::Signal:
-      type="signal"; break;
-    case MemberDef::Slot:
-      type="slot"; break;
-    case MemberDef::Friend:
-      type="ffunc"; break;
-    case MemberDef::DCOP:
-      type="dcop"; break;
-    case MemberDef::Property:
-      if (cd && cd->compoundType()==ClassDef::Protocol) 
-        type="intfp";
-      else 
-        type="instp";
-      break;
-    case MemberDef::Event:
-      type="event"; break;
+      {
+        type = "cl";
+      }
+      IncludeInfo *ii = cd->includeInfo();
+      if (ii)
+      {
+        decl=ii->includeName;
+        if (decl.isEmpty())
+        {
+          decl=ii->local;
+        }
+      }
+    }
+    else if (nd)
+    {
+      scope = nd->name();
+      type = "ns";
+    }
+    if (m_scopes.find(context->getOutputFileBase())==0)
+    {
+      writeToken(m_tts,context,type,lang,0,0,decl);
+      m_scopes.append(context->getOutputFileBase(),(void*)0x8);
+    }
   }
-  writeToken(m_tts,md,type,lang,scope,md->anchor());
 }
 
-void DocSets::writeToken(QTextStream &t,
+void DocSets::writeToken(FTextStream &t,
                          const Definition *d,
                          const QCString &type,
                          const QCString &lang,
@@ -384,9 +426,18 @@ void DocSets::writeToken(QTextStream &t,
   QString name = d->name();
   if (name.right(2)=="-p")  name=name.left(name.length()-2);
   t << "      <Name>" << convertToXML(name) << "</Name>" << endl;
-  t << "      <APILanguage>" << lang << "</APILanguage>" << endl;
-  t << "      <Type>" << type << "</Type>" << endl;
-  t << "      <Scope>" << convertToXML(scope) << "</Scope>" << endl;
+  if (!lang.isEmpty())
+  {
+    t << "      <APILanguage>" << lang << "</APILanguage>" << endl;
+  }
+  if (!type.isEmpty())
+  {
+    t << "      <Type>" << type << "</Type>" << endl;
+  }
+  if (scope)
+  {
+    t << "      <Scope>" << convertToXML(scope) << "</Scope>" << endl;
+  }
   t << "    </TokenIdentifier>" << endl;
   t << "    <Path>" << d->getOutputFileBase() 
                     << Doxygen::htmlFileExtension << "</Path>" << endl;
@@ -397,7 +448,7 @@ void DocSets::writeToken(QTextStream &t,
   QCString tooltip = d->briefDescriptionAsTooltip();
   if (!tooltip.isEmpty())
   {
-    t << "    <Abstract>" << tooltip << "</Abstract>" << endl;
+    t << "    <Abstract>" << convertToXML(tooltip) << "</Abstract>" << endl;
   }
   if (decl)
   {
