@@ -3,7 +3,7 @@
  * $Id: doxygen.h,v 1.39 2001/03/19 19:27:40 root Exp $
  *
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -20,9 +20,9 @@
 #define DOXYGEN_H
 
 #include "qtbc.h"
-#include <qtextstream.h>
 #include <qdatetime.h>
 #include <qcache.h>
+#include "ftextstream.h"
 #include "groupdef.h"
 #include "filedef.h"
 #include "classdef.h"
@@ -95,7 +95,7 @@ class Doxygen
     static QStrList                  tagfileList;
     static MemberNameSDict          *memberNameSDict;
     static MemberNameSDict          *functionNameSDict;
-    static QTextStream               tagFile;
+    static FTextStream               tagFile;
     static SectionDict               sectionDict;
     static StringDict                namespaceAliasDict;
     static GroupSDict               *groupSDict;
@@ -112,7 +112,7 @@ class Doxygen
     static QCString                  htmlFileExtension;
     static bool                      parseSourcesNeeded;
     static QTime                     runningTime;
-    //static SearchIndex              *searchIndex;
+    static SearchIndex              *searchIndex;
     static QDict<DefinitionIntf>    *symbolMap;
     static bool                      outputToWizard;
     static QDict<int>               *htmlDirMap;
