@@ -2,7 +2,7 @@
  *
  * $Id: filedef.cpp,v 1.55 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -92,7 +92,9 @@ FileDef::FileDef(const char *p,const char *nm,
   {
     docname.prepend(stripFromPath(path.copy()));
   }
-  m_isJava          = name().right(5)==".java";
+  SrcLangExt lang   = getLanguageFromFileName(name());
+  m_isJava          = lang==SrcLangExt_Java;
+  m_isCSharp        = lang==SrcLangExt_CSharp;
   memberGroupSDict = 0;
   acquireFileVersion();
   m_subGrouping=Config_getBool("SUBGROUPING");
@@ -262,10 +264,8 @@ void FileDef::writeIncludeFiles(OutputList &ol)
       bool isIDLorJava = FALSE;
       if (fd)
       {
-        isIDLorJava = fd->name().right(4)==".idl" ||   // M$ or Corba IDL
-                      fd->name().right(5)==".pidl" ||
-                      fd->name().right(5)==".java" ||  // Sun's Java
-                      fd->name().right(4)==".jsl";     // M$ J#
+        SrcLangExt lang   = getLanguageFromFileName(fd->name());
+        isIDLorJava = lang==SrcLangExt_IDL || lang==SrcLangExt_Java;
       }
       ol.startTypewriter();
       if (isIDLorJava) // IDL/Java include
@@ -456,6 +456,41 @@ void FileDef::writeAuthorSection(OutputList &ol)
   ol.popGeneratorState();
 }
 
+void FileDef::writeSummaryLinks(OutputList &ol)
+{
+  ol.pushGeneratorState();
+  ol.disableAllBut(OutputGenerator::Html);
+  QListIterator<LayoutDocEntry> eli(
+      LayoutDocManager::instance().docEntries(LayoutDocManager::File));
+  LayoutDocEntry *lde;
+  bool first=TRUE;
+  for (eli.toFirst();(lde=eli.current());++eli)
+  {
+    if ((lde->kind()==LayoutDocEntry::FileClasses && classSDict && classSDict->declVisible()) || 
+        (lde->kind()==LayoutDocEntry::FileNamespaces && namespaceSDict && namespaceSDict->declVisible())
+       )
+    {
+      LayoutDocEntrySection *ls = (LayoutDocEntrySection*)lde;
+      QCString label = lde->kind()==LayoutDocEntry::FileClasses ? "nested-classes" : "namespaces";
+      writeSummaryLink(ol,label,ls->title,first);
+    }
+    else if (lde->kind()==LayoutDocEntry::MemberDecl)
+    {
+      LayoutDocEntryMemberDecl *lmd = (LayoutDocEntryMemberDecl*)lde;
+      MemberList * ml = getMemberList(lmd->type);
+      if (ml && ml->declVisible())
+      {
+        writeSummaryLink(ol,ml->listTypeAsString(),lmd->title,first);
+      }
+    }
+  }
+  if (!first)
+  {
+    ol.writeString("  </div>\n");
+  }
+  ol.popGeneratorState();
+}
+
 /*! Write the documentation page for this file to the file of output
     generators \a ol. 
 */
@@ -484,9 +519,8 @@ void FileDef::writeDocumentation(OutputList &ol)
     startFile(ol,getOutputFileBase(),name(),pageTitle,HLI_FileVisible,TRUE);
     getDirDef()->writeNavigationPath(ol);
     ol.endQuickIndices();
-    ol.startContents();
     QCString pageTitleShort=theTranslator->trFileReference(name());
-    startTitle(ol,getOutputFileBase());
+    startTitle(ol,getOutputFileBase(),this);
     ol.pushGeneratorState();
       ol.disableAllBut(OutputGenerator::Html);
       ol.parseText(pageTitleShort); // Html only
@@ -500,11 +534,14 @@ void FileDef::writeDocumentation(OutputList &ol)
   else
   {
     startFile(ol,getOutputFileBase(),name(),pageTitle,HLI_FileVisible);
-    startTitle(ol,getOutputFileBase());
+    startTitle(ol,getOutputFileBase(),this);
     ol.parseText(pageTitle);
     addGroupListToTitle(ol,this);
     endTitle(ol,getOutputFileBase(),title);
   }
+
+  ol.startContents();
+
   if (!fileVersion.isEmpty())
   {
     ol.disableAllBut(OutputGenerator::Html);
@@ -514,11 +551,11 @@ void FileDef::writeDocumentation(OutputList &ol)
     ol.enableAll();
   }
   
-  //if (Config_getBool("SEARCHENGINE"))
-  //{
-  //  Doxygen::searchIndex->setCurrentDoc(pageTitle,getOutputFileBase());
-  //  Doxygen::searchIndex->addWord(localName(),TRUE);
-  //}
+  if (Doxygen::searchIndex)
+  {
+    Doxygen::searchIndex->setCurrentDoc(pageTitle,getOutputFileBase());
+    Doxygen::searchIndex->addWord(localName(),TRUE);
+  }
   
   if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
   {
@@ -725,7 +762,6 @@ void FileDef::writeSource(OutputList &ol)
     startFile(ol,getSourceFileBase(),0,pageTitle,HLI_FileVisible,TRUE);
     getDirDef()->writeNavigationPath(ol);
     ol.endQuickIndices();
-    ol.startContents();
     startTitle(ol,getOutputFileBase());
     ol.parseText(name());
     endTitle(ol,getOutputFileBase(),title);
@@ -738,6 +774,8 @@ void FileDef::writeSource(OutputList &ol)
     endTitle(ol,getSourceFileBase(),0);
   }
 
+  ol.startContents();
+
   if (isLinkable())
   {
     if (latexSourceCode) ol.disable(OutputGenerator::Latex);
@@ -755,6 +793,7 @@ void FileDef::writeSource(OutputList &ol)
             FALSE,0,this
            );
   ol.endCodeFragment();
+  ol.endContents();
   endFile(ol);
   ol.enableAll();
 }
@@ -1094,8 +1133,10 @@ void FileDef::addListReferences()
   {
     LockingPtr< QList<ListItemInfo> > xrefItems = xrefListItems();
     addRefItem(xrefItems.pointer(),
+               getOutputFileBase(),
                theTranslator->trFile(TRUE,TRUE),
-               getOutputFileBase(),name()
+               getOutputFileBase(),name(),
+               0
               );
   }
   if (memberGroupSDict)
@@ -1423,7 +1464,7 @@ void FileDef::acquireFileVersion()
     FILE *f=portable_popen(cmd,"r");
     if (!f)
     {
-      err("Error: could not execute %s\n",vercmd.data());
+      err("error: could not execute %s\n",vercmd.data());
       return;
     }
     const int bufSize=1024;
@@ -1491,12 +1532,16 @@ void FileDef::addMemberToList(MemberList::ListType lt,MemberDef *md)
   static bool sortBriefDocs = Config_getBool("SORT_BRIEF_DOCS");
   static bool sortMemberDocs = Config_getBool("SORT_MEMBER_DOCS");
   MemberList *ml = createMemberList(lt);
-  if (((ml->listType()&MemberList::declarationLists) && sortBriefDocs) ||
-      ((ml->listType()&MemberList::documentationLists) && sortMemberDocs)
-     )
+  ml->setNeedsSorting(
+       ((ml->listType()&MemberList::declarationLists) && sortBriefDocs) ||
+       ((ml->listType()&MemberList::documentationLists) && sortMemberDocs));
+  ml->append(md);
+#if 0
+  if (ml->needsSorting())
     ml->inSort(md);
   else
     ml->append(md);
+#endif
   if (lt&MemberList::documentationLists)
   {
     ml->setInFile(TRUE);
@@ -1504,6 +1549,16 @@ void FileDef::addMemberToList(MemberList::ListType lt,MemberDef *md)
   if (ml->listType()&MemberList::declarationLists) md->setSectionList(this,ml);
 }
 
+void FileDef::sortMemberLists()
+{
+  MemberList *ml = m_memberLists.first();
+  while (ml)
+  {
+    if (ml->needsSorting()) { ml->sort(); ml->setNeedsSorting(FALSE); }
+    ml = m_memberLists.next();
+  }
+}
+
 MemberList *FileDef::getMemberList(MemberList::ListType lt) const
 {
   FileDef *that = (FileDef*)this;
@@ -1548,3 +1603,23 @@ bool FileDef::isLinkableInProject() const
   return hasDocumentation() && !isReference() && showFiles;
 }
 
+bool FileDef::includes(FileDef *incFile,QDict<FileDef> *includedFiles) const
+{
+  if (incFile==this) return TRUE;
+  //printf("%s::includes(%s)\n",name().data(),incFile->name().data());
+  includedFiles->insert(absFilePath(),this);
+  if (includeList)
+  {
+    QListIterator<IncludeInfo> ili(*includeList);
+    IncludeInfo *ii;
+    for (;(ii=ili.current());++ili)
+    {
+      if (ii->fileDef && 
+          includedFiles->find(ii->fileDef->absFilePath())==0 &&
+          ii->fileDef->includes(incFile,includedFiles)) return TRUE;
+    }
+  }
+  return FALSE;
+}
+
+
