@@ -1,8 +1,19 @@
 /******************************************************************************
  * ftvhelp.cpp,v 1.0 2000/09/06 16:09:00
  *
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ *
+ * Permission to use, copy, modify, and distribute this software and its
+ * documentation under the terms of the GNU General Public License is hereby 
+ * granted. No representations are made about the suitability of this software 
+ * for any purpose. It is provided "as is" without express or implied warranty.
+ * See the GNU General Public License for more details.
+ *
+ * Documents produced by Doxygen are derivative works derived from the
+ * input used in their production; they are not affected by this license.
+ *
  * Contributed by Kenney Wong <kwong@ea.com>
- * Modified by Dimitri van Heesch (c) 2003
+ * Modified by Dimitri van Heesch
  *
  * Folder Tree View for offline help on browsers that do not support HTML Help.
  */
@@ -422,7 +433,7 @@ void FTVHelp::addContentsItem(bool isDir,
 
 static int folderId=1;
 
-void FTVHelp::generateIndent(QTextStream &t, FTVNode *n,int level)
+void FTVHelp::generateIndent(FTextStream &t, FTVNode *n,int level)
 {
   if (n->parent)
   {
@@ -467,9 +478,8 @@ void FTVHelp::generateIndent(QTextStream &t, FTVNode *n,int level)
   }
 }
 
-void FTVHelp::generateLink(QTextStream &t,FTVNode *n)
+void FTVHelp::generateLink(FTextStream &t,FTVNode *n)
 {
-  QCString *dest;
   //printf("FTVHelp::generateLink(ref=%s,file=%s,anchor=%s\n",
   //    n->ref.data(),n->file.data(),n->anchor.data());
   if (n->file.isEmpty()) // no link
@@ -481,19 +491,14 @@ void FTVHelp::generateLink(QTextStream &t,FTVNode *n)
     if (!n->ref.isEmpty()) // link to entity imported via tag file
     {
       t << "<a class=\"elRef\" ";
-      t << "doxygen=\"" << n->ref << ":";
-      if ((dest=Doxygen::tagDestinationDict[n->ref])) t << *dest << "/";
-      t << "\" ";
+      t << externalLinkTarget() << externalRef("",n->ref,FALSE);
     }
     else // local link
     {
       t << "<a class=\"el\" ";
     }
     t << "href=\"";
-    if (!n->ref.isEmpty())
-    {
-      if ((dest=Doxygen::tagDestinationDict[n->ref])) t << *dest << "/";
-    }
+    t << externalRef("",n->ref,TRUE);
     t << n->file << Doxygen::htmlFileExtension;
     if (!n->anchor.isEmpty()) t << "#" << n->anchor;
     if (m_topLevelIndex)
@@ -509,7 +514,7 @@ void FTVHelp::generateLink(QTextStream &t,FTVNode *n)
   }
 }
 
-void FTVHelp::generateTree(QTextStream &t, const QList<FTVNode> &nl,int level)
+void FTVHelp::generateTree(FTextStream &t, const QList<FTVNode> &nl,int level)
 {
   QCString spaces;
   spaces.fill(' ',level*2+8);
@@ -556,106 +561,15 @@ void FTVHelp::generateTreeViewImages()
     }
     else
     {
-      fprintf(stderr,"Warning: Cannot open file %s for writing\n",fileName.data());
+      fprintf(stderr,"warning: Cannot open file %s for writing\n",fileName.data());
     }
     f.close();
     p++;
   }
 } 
 
-void FTVHelp::generateTreeView(QString* OutString)
+void FTVHelp::generateScript(FTextStream &t)
 {
-  QCString fileName;
-  QFile f;
-  static bool searchEngine = Config_getBool("SEARCHENGINE");
-  
-  generateTreeViewImages();
-  
-  // If top level index, generate alternative index.html as a frame
-  if (m_topLevelIndex)
-  {
-    fileName=Config_getString("HTML_OUTPUT")+"/index"+Doxygen::htmlFileExtension;
-    f.setName(fileName);
-    if (!f.open(IO_WriteOnly))
-    {
-      err("Cannot open file %s for writing!\n",fileName.data());
-      return;
-    }
-    else
-    {
-      QTextStream t(&f);
-#if QT_VERSION >= 200
-      t.setEncoding(QTextStream::UnicodeUTF8);
-#endif
-      //t << "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Frameset//EN\">\n";
-      t << "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Frameset//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-frameset.dtd\">\n";
-      t << "<html xmlns=\"http://www.w3.org/1999/xhtml\">\n<head>\n";
-      t << "<meta http-equiv=\"Content-Type\" content=\"text/xhtml;charset=UTF-8\"/>\n";
-      t << "<title>"; 
-      if (Config_getString("PROJECT_NAME").isEmpty())
-      {
-        t << "Doxygen Documentation";
-      }
-      else
-      {
-        t << Config_getString("PROJECT_NAME");
-      }
-      t << "</title>\n</head>" << endl;
-      t << "<frameset cols=\"" << Config_getInt("TREEVIEW_WIDTH") << ",*\">" << endl;
-      t << "  <frame src=\"tree" << Doxygen::htmlFileExtension << "\" name=\"treefrm\"/>" << endl;
-      t << "  <frame src=\"main" << Doxygen::htmlFileExtension << "\" name=\"basefrm\"/>" << endl;
-      t << "  <noframes>" << endl;
-      t << "    <body>" << endl;
-      t << "    <a href=\"main" << Doxygen::htmlFileExtension << "\">Frames are disabled. Click here to go to the main page.</a>" << endl;
-      t << "    </body>" << endl;
-      t << "  </noframes>" << endl;
-      t << "</frameset>" << endl;
-      t << "</html>" << endl;
-      f.close();
-    }
-  }
-
-  // Generate tree view
-  if (!OutString)
-    OutString = new QString;
-  QTextOStream t(OutString);
-  t.setEncoding(QTextStream::UnicodeUTF8);
-
-  if (m_topLevelIndex)
-  {
-    if (searchEngine)
-    {
-      t << "<!-- This comment will put IE 6, 7 and 8 in quirks mode -->" << endl;
-    }
-    t << "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">\n";
-    t << "<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"en\" lang=\"en\">\n";
-    t << "  <head>\n";
-    t << "    <meta http-equiv=\"Content-Type\" content=\"text/xhtml;charset=UTF-8\"/>\n";
-    t << "    <meta http-equiv=\"Content-Style-Type\" content=\"text/css\" />\n";
-    t << "    <meta http-equiv=\"Content-Language\" content=\"en\" />\n";
-    if (searchEngine)
-    {
-      t << "    <link href=\"search/search.css\" rel=\"stylesheet\" type=\"text/css\"/>" << endl;
-      t << "    <script type=\"text/javaScript\" src=\"search/search.js\"></script>" << endl;
-    }
-    t << "    <link rel=\"stylesheet\" href=\"";
-    QCString cssname=Config_getString("HTML_STYLESHEET");
-    if (cssname.isEmpty())
-    {
-      t << "doxygen.css";
-    }
-    else
-    {
-      QFileInfo cssfi(cssname);
-      if (!cssfi.exists())
-      {
-        err("Error: user specified HTML style sheet file does not exist!\n");
-      }
-      t << cssfi.fileName();
-    }
-    t << "\"/>" << endl;
-    t << "    <title>TreeView</title>\n";
-  }
   t << "    <script type=\"text/javascript\">\n";
   t << "    <!-- // Hide script from old browsers\n";
   t << "    \n";
@@ -714,12 +628,116 @@ void FTVHelp::generateTreeView(QString* OutString)
   t << "\n";
   t << "    // End script hiding -->        \n";
   t << "    </script>\n";
-  if (m_topLevelIndex)
+}
+
+void FTVHelp::generateTreeViewInline(FTextStream &t)
+{
+  generateScript(t);
+  t << "    <div class=\"directory-alt\">\n";
+  t << "      <br/>\n";
+  t << "      <div style=\"display: block;\">\n";
+
+  generateTree(t,m_indentNodes[0],0);
+
+  t << "      </div>\n";
+  t << "    </div>\n";
+}
+
+
+void FTVHelp::generateTreeView()
+{
+  QCString fileName;
+  QFile f;
+  static bool searchEngine = Config_getBool("SEARCHENGINE");
+  static bool serverBasedSearch = Config_getBool("SERVER_BASED_SEARCH");
+  generateTreeViewImages();
+  
+  fileName=Config_getString("HTML_OUTPUT")+"/index"+Doxygen::htmlFileExtension;
+  f.setName(fileName);
+  if (!f.open(IO_WriteOnly))
   {
+    err("Cannot open file %s for writing!\n",fileName.data());
+    return;
+  }
+  else
+  {
+    FTextStream t(&f);
+    //t << "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Frameset//EN\">\n";
+    t << "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Frameset//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-frameset.dtd\">\n";
+    t << "<html xmlns=\"http://www.w3.org/1999/xhtml\">\n<head>\n";
+    t << "<meta http-equiv=\"Content-Type\" content=\"text/xhtml;charset=UTF-8\"/>\n";
+    t << "<title>"; 
+    if (Config_getString("PROJECT_NAME").isEmpty())
+    {
+      t << "Doxygen Documentation";
+    }
+    else
+    {
+      t << Config_getString("PROJECT_NAME");
+    }
+    t << "</title>\n</head>" << endl;
+    t << "<frameset cols=\"" << Config_getInt("TREEVIEW_WIDTH") << ",*\">" << endl;
+    t << "  <frame src=\"tree" << Doxygen::htmlFileExtension << "\" name=\"treefrm\"/>" << endl;
+    t << "  <frame src=\"main" << Doxygen::htmlFileExtension << "\" name=\"basefrm\"/>" << endl;
+    t << "  <noframes>" << endl;
+    t << "    <body>" << endl;
+    t << "    <a href=\"main" << Doxygen::htmlFileExtension << "\">Frames are disabled. Click here to go to the main page.</a>" << endl;
+    t << "    </body>" << endl;
+    t << "  </noframes>" << endl;
+    t << "</frameset>" << endl;
+    t << "</html>" << endl;
+    f.close();
+  }
+
+  // Generate tree view
+  fileName=Config_getString("HTML_OUTPUT")+"/tree"+Doxygen::htmlFileExtension;
+  f.setName(fileName);
+  if (!f.open(IO_WriteOnly))
+  {
+    err("Cannot open file %s for writing!\n",fileName.data());
+    return;
+  }
+  else
+  {
+    FTextStream t(&f);
+
+    //if (searchEngine)
+    //{
+    //  t << "<!-- This comment will put IE 6, 7 and 8 in quirks mode -->" << endl;
+    //}
+    t << "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">\n";
+    t << "<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"en\" lang=\"en\">\n";
+    t << "  <head>\n";
+    t << "    <meta http-equiv=\"Content-Type\" content=\"text/xhtml;charset=UTF-8\"/>\n";
+    t << "    <meta http-equiv=\"Content-Style-Type\" content=\"text/css\" />\n";
+    t << "    <meta http-equiv=\"Content-Language\" content=\"en\" />\n";
+    if (searchEngine)
+    {
+      t << "    <link href=\"search/search.css\" rel=\"stylesheet\" type=\"text/css\"/>" << endl;
+      t << "    <script type=\"text/javaScript\" src=\"search/search.js\"></script>" << endl;
+    }
+    t << "    <link rel=\"stylesheet\" href=\"";
+    QCString cssname=Config_getString("HTML_STYLESHEET");
+    if (cssname.isEmpty())
+    {
+      t << "doxygen.css";
+    }
+    else
+    {
+      QFileInfo cssfi(cssname);
+      if (!cssfi.exists())
+      {
+        err("Error: user specified HTML style sheet file does not exist!\n");
+      }
+      t << cssfi.fileName();
+    }
+    t << "\"/>" << endl;
+    t << "    <title>TreeView</title>\n";
+    generateScript(t);
     t << "  </head>\n";
     t << "\n";
     t << "  <body class=\"ftvtree\"";
-    if (searchEngine)
+    if (searchEngine && !serverBasedSearch)
     {
       t << " onload='searchBox.OnSelectItem(0);'";
     }
@@ -730,23 +748,44 @@ void FTVHelp::generateTreeView(QString* OutString)
       t << "      var searchBox = new SearchBox(\"searchBox\", \"search\", true, '" 
         << theTranslator->trSearch() << "');\n";
       t << "      --></script>\n";
-      t << "      <div id=\"MSearchBox\" class=\"MSearchBoxInactive\">\n";
-      t << "      <div class=\"MSearchBoxRow\"><span class=\"MSearchBoxLeft\">\n";
-      t << "      <a id=\"MSearchClose\" href=\"javascript:searchBox.CloseResultsWindow()\">"
-        << "<img id=\"MSearchCloseImg\" border=\"0\" src=\"search/close.png\" alt=\"\"/></a>\n";
-      t << "      <input type=\"text\" id=\"MSearchField\" value=\"" 
-        << theTranslator->trSearch() << "\" accesskey=\"S\"\n";
-      t << "           onfocus=\"searchBox.OnSearchFieldFocus(true)\" \n";
-      t << "           onblur=\"searchBox.OnSearchFieldFocus(false)\" \n";
-      t << "           onkeyup=\"searchBox.OnSearchFieldChange(event)\"/>\n";
-      t << "      </span><span class=\"MSearchBoxRight\">\n";
-      t << "      <img id=\"MSearchSelect\" src=\"search/search.png\"\n";
-      t << "           onmouseover=\"return searchBox.OnSearchSelectShow()\"\n";
-      t << "           onmouseout=\"return searchBox.OnSearchSelectHide()\"\n";
-      t << "           alt=\"\"/>\n";
-      t << "      </span></div><div class=\"MSearchBoxSpacer\">&nbsp;</div>\n";
-      t << "      </div>\n";
-      HtmlGenerator::writeSearchFooter(t,QCString());
+      if (!serverBasedSearch)
+      {
+        t << "      <div class=\"tabsearch\">\n";
+        t << "        <div id=\"MSearchBox\" class=\"MSearchBoxInactive\">\n";
+        t << "          <span class=\"left\">\n";
+        t << "            <a id=\"MSearchClose\" href=\"javascript:searchBox.CloseResultsWindow()\">"
+          << "<img id=\"MSearchCloseImg\" border=\"0\" src=\"search/close.png\" alt=\"\"/></a>\n";
+        t << "            <input type=\"text\" id=\"MSearchField\" value=\"" 
+          << theTranslator->trSearch() << "\" accesskey=\"S\"\n";
+        t << "                   onfocus=\"searchBox.OnSearchFieldFocus(true)\" \n";
+        t << "                   onblur=\"searchBox.OnSearchFieldFocus(false)\" \n";
+        t << "                   onkeyup=\"searchBox.OnSearchFieldChange(event)\"/>\n";
+        t << "          </span><span class=\"right\">\n";
+        t << "            <img id=\"MSearchSelect\" src=\"search/mag_sel.png\"\n";
+        t << "                 onmouseover=\"return searchBox.OnSearchSelectShow()\"\n";
+        t << "                 onmouseout=\"return searchBox.OnSearchSelectHide()\"\n";
+        t << "                 alt=\"\"/>\n";
+        t << "          </span>\n";
+        t << "        </div>\n";
+        t << "      </div>\n";
+        HtmlGenerator::writeSearchFooter(t,QCString());
+      }
+      else
+      {
+        t << "      <div class=\"tabsearch\">\n";
+        t << "        <div id=\"MSearchBox\" class=\"MSearchBoxInactive\">\n";
+        t << "          <span class=\"left\">\n";
+        t << "            <form id=\"FSearchBox\" action=\"search.php\" method=\"get\" target=\"basefrm\">\n";
+        t << "              <img id=\"MSearchSelect\" src=\"search/mag.png\" alt=\"\"/>\n";
+        t << "              <input type=\"text\" id=\"MSearchField\" name=\"query\" value=\""
+          << theTranslator->trSearch() << "\" size=\"20\" accesskey=\"S\" \n";
+        t << "                     onfocus=\"searchBox.OnSearchFieldFocus(true)\" \n";
+        t << "                     onblur=\"searchBox.OnSearchFieldFocus(false)\"/>\n";
+        t << "            </form>\n";
+        t << "          </span><span class=\"right\"></span>\n";
+        t << "        </div>\n";
+        t << "      </div>\n";
+      }
     }
     t << "    <div class=\"directory\">\n";
     t << "      <h3 class=\"swap\"><span>";
@@ -760,41 +799,17 @@ void FTVHelp::generateTreeView(QString* OutString)
       t << projName;
     }
     t << "</span></h3>\n";
-  }
-  else
-  {
-    t << "    <div class=\"directory-alt\">\n";
-    t << "      <br/>\n";
-  }
-  t << "      <div style=\"display: block;\">\n";
+    t << "      <div style=\"display: block;\">\n";
 
-  generateTree(t,m_indentNodes[0],0);
+    generateTree(t,m_indentNodes[0],0);
 
-  t << "      </div>\n";
-  t << "    </div>\n";
+    t << "      </div>\n";
+    t << "    </div>\n";
   
-  if (m_topLevelIndex)
-  {
     t << "  </body>\n";
     t << "</html>\n";
-  }
   
-  if (m_topLevelIndex)
-  {
-    fileName=Config_getString("HTML_OUTPUT")+"/tree"+Doxygen::htmlFileExtension;
-    f.setName(fileName);
-    if (!f.open(IO_WriteOnly))
-    {
-      err("Cannot open file %s for writing!\n",fileName.data());
-      return;
-    }
-    else
-    {
-      QTextStream t(&f);
-      t.setEncoding(QTextStream::UnicodeUTF8);
-      t << *OutString << endl;
-      f.close();
-    }
+    f.close();
   }
 }
 
