@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -34,6 +34,34 @@
 static const int NUM_HTML_LIST_TYPES = 4;
 static const char types[][NUM_HTML_LIST_TYPES] = {"1", "a", "i", "A"};
 
+static QCString convertIndexWordToAnchor(const QString &word)
+{
+  static char hex[] = "0123456789abcdef";
+  uint i;
+  QCString result;
+  for (i=0;i<word.length();i++)
+  {
+    int c = word.at(i);
+    if (isId(c))
+    {
+      result+=c;
+    }
+    else if (isspace(c))
+    {
+      result+="_";
+    }
+    else
+    {
+      char cs[3];
+      cs[0]=hex[c>>4];
+      cs[1]=hex[c&0xf];
+      cs[2]=0;
+      result+=cs;
+    }
+  }
+  return result;
+}
+
 static bool mustBeOutsideParagraph(DocNode *n)
 {
   switch (n->kind())
@@ -52,6 +80,8 @@ static bool mustBeOutsideParagraph(DocNode *n)
           /* <h?> */
         case DocNode::Kind_Section:
         case DocNode::Kind_HtmlHeader:
+          /* \internal */
+        case DocNode::Kind_Internal:
           /* <div> */
         case DocNode::Kind_Verbatim:
         case DocNode::Kind_Include:
@@ -59,6 +89,11 @@ static bool mustBeOutsideParagraph(DocNode *n)
         case DocNode::Kind_SecRefList:
           /* <hr> */
         case DocNode::Kind_HorRuler:
+          /* CopyDoc gets paragraph markers from the wrapping DocPara node,
+           * but needs to insert them for all documentation being copied to
+           * preserve formatting.
+           */
+        case DocNode::Kind_Copy:
           return TRUE;
         case DocNode::Kind_StyleChange:
           return ((DocStyleChange*)n)->style()==DocStyleChange::Preformatted ||
@@ -94,7 +129,7 @@ static QString htmlAttribsToString(const HtmlAttribList &attribs)
 
 //-------------------------------------------------------------------------
 
-HtmlDocVisitor::HtmlDocVisitor(QTextStream &t,CodeOutputInterface &ci,
+HtmlDocVisitor::HtmlDocVisitor(FTextStream &t,CodeOutputInterface &ci,
                                const char *langExt) 
   : DocVisitor(DocVisitor_Html), m_t(t), m_ci(ci), m_insidePre(FALSE), 
                                  m_hide(FALSE), m_langExt(langExt)
@@ -169,7 +204,7 @@ void HtmlDocVisitor::visit(DocSymbol *s)
     case DocSymbol::AElig:   m_t << "&AElig;"; break;
     case DocSymbol::Aelig:   m_t << "&aelig;"; break;
     default:
-                             err("Error: unknown symbol found\n");
+                             err("error: unknown symbol found\n");
   }
 }
 
@@ -273,7 +308,7 @@ void HtmlDocVisitor::visit(DocVerbatim *s)
       forceEndParagraph(s);
       m_t << PREFRAG_START;
       Doxygen::parserManager->getParser(m_langExt)
-                            ->parseCode(m_ci,s->context(),s->text().latin1(),
+                            ->parseCode(m_ci,s->context(),s->text(),
                                         s->isExample(),s->exampleFile());
       m_t << PREFRAG_END;
       forceStartParagraph(s);
@@ -293,7 +328,7 @@ void HtmlDocVisitor::visit(DocVerbatim *s)
     case DocVerbatim::XmlOnly: 
       /* nothing */ 
       break;
-     
+
     case DocVerbatim::Dot:
       {
         static int dotindex = 1;
@@ -370,7 +405,7 @@ void HtmlDocVisitor::visit(DocInclude *inc)
       Doxygen::parserManager->getParser(inc->extension())
                             ->parseCode(m_ci,                 
                                         inc->context(),
-                                        inc->text().latin1(),
+                                        inc->text(),
                                         inc->isExample(),
                                         inc->exampleFile(),
                                         0,   // fd
@@ -390,7 +425,7 @@ void HtmlDocVisitor::visit(DocInclude *inc)
          Doxygen::parserManager->getParser(inc->extension())
                                ->parseCode(m_ci,
                                            inc->context(),
-                                           inc->text().latin1(),
+                                           inc->text(),
                                            inc->isExample(),
                                            inc->exampleFile(), &fd);
          m_t << PREFRAG_END;
@@ -429,7 +464,7 @@ void HtmlDocVisitor::visit(DocIncOperator *op)
     {
       Doxygen::parserManager->getParser(m_langExt)
                             ->parseCode(m_ci,op->context(),
-                                op->text().latin1(),op->isExample(),
+                                op->text(),op->isExample(),
                                 op->exampleFile());
     }
     pushEnabled();
@@ -470,8 +505,20 @@ void HtmlDocVisitor::visit(DocFormula *f)
   }
 }
 
-void HtmlDocVisitor::visit(DocIndexEntry *)
+void HtmlDocVisitor::visit(DocIndexEntry *e)
 {
+  QCString anchor = convertIndexWordToAnchor(e->entry());
+  if (e->member()) 
+  {
+    anchor.prepend(e->member()->anchor()+"_");
+  }
+  m_t << "<a name=\"" << anchor << "\"></a>";
+  //printf("*** DocIndexEntry: word='%s' scope='%s' member='%s'\n",
+  //       e->entry().data(),
+  //       e->scope()  ? e->scope()->name().data()  : "<null>",
+  //       e->member() ? e->member()->name().data() : "<null>"
+  //      );
+  Doxygen::indexList.addIndexItem(e->scope(),e->member(),anchor,e->entry());
 }
 
 void HtmlDocVisitor::visit(DocSimpleSectSep *)
@@ -579,7 +626,7 @@ bool isSeparatedParagraph(DocSimpleSect *parent,DocPara *par)
   return FALSE;
 }
 
-int getParagraphContext(DocPara *p,bool &isFirst,bool &isLast)
+static int getParagraphContext(DocPara *p,bool &isFirst,bool &isLast)
 {
   int t=0;
   isFirst=FALSE;
@@ -624,6 +671,12 @@ int getParagraphContext(DocPara *p,bool &isFirst,bool &isLast)
         if (isFirst) t=2;
         if (isLast)  t=4;
         break;
+      case DocNode::Kind_HtmlCell:
+        isFirst=isFirstChildNode((DocHtmlCell*)p->parent(),p);
+        isLast =isLastChildNode ((DocHtmlCell*)p->parent(),p);
+        if (isFirst) t=5;
+        if (isLast)  t=6;
+        break;
       case DocNode::Kind_SimpleSect:
         isFirst=isFirstChildNode((DocSimpleSect*)p->parent(),p);
         isLast =isLastChildNode ((DocSimpleSect*)p->parent(),p);
@@ -659,6 +712,7 @@ void HtmlDocVisitor::visitPre(DocPara *p)
     switch (p->parent()->kind()) 
     {
       case DocNode::Kind_Section:
+      case DocNode::Kind_Internal:
       case DocNode::Kind_HtmlListItem:
       case DocNode::Kind_HtmlDescData:
       case DocNode::Kind_HtmlCell:
@@ -666,6 +720,7 @@ void HtmlDocVisitor::visitPre(DocPara *p)
       case DocNode::Kind_AutoListItem:
       case DocNode::Kind_SimpleSect:
       case DocNode::Kind_XRefItem:
+      case DocNode::Kind_Copy:
         needsTag = TRUE;
         break;
       case DocNode::Kind_Root:
@@ -701,12 +756,14 @@ void HtmlDocVisitor::visitPre(DocPara *p)
   // this allows us to mark the tag with a special class so we can
   // fix the otherwise ugly spacing.
   int t;
-  static const char *contexts[5] = 
-  { "", 
-    " class=\"startli\"",
-    " class=\"startdd\"",
-    " class=\"endli\"",
-    " class=\"enddd\""
+  static const char *contexts[7] = 
+  { "",                     // 0
+    " class=\"startli\"",   // 1
+    " class=\"startdd\"",   // 2
+    " class=\"endli\"",     // 3
+    " class=\"enddd\"",     // 4
+    " class=\"starttd\"",   // 5
+    " class=\"endtd\""      // 6
   };
   bool isFirst;
   bool isLast;
@@ -736,6 +793,7 @@ void HtmlDocVisitor::visitPost(DocPara *p)
     switch (p->parent()->kind()) 
     {
       case DocNode::Kind_Section:
+      case DocNode::Kind_Internal:
       case DocNode::Kind_HtmlListItem:
       case DocNode::Kind_HtmlDescData:
       case DocNode::Kind_HtmlCell:
@@ -743,6 +801,7 @@ void HtmlDocVisitor::visitPost(DocPara *p)
       case DocNode::Kind_AutoListItem:
       case DocNode::Kind_SimpleSect:
       case DocNode::Kind_XRefItem:
+      case DocNode::Kind_Copy:
         needsTag = TRUE;
         break;
       case DocNode::Kind_Root:
@@ -892,9 +951,9 @@ void HtmlDocVisitor::visitPre(DocSection *s)
   forceEndParagraph(s);
   m_t << "<h" << s->level()+1 << ">";
   m_t << "<a class=\"anchor\" id=\"" << s->anchor();
-  m_t << "\">" << endl;
+  m_t << "\"></a>" << endl;
   filter(convertCharEntitiesToUTF8(s->title().data()));
-  m_t << "</a></h" << s->level()+1 << ">\n";
+  m_t << "</h" << s->level()+1 << ">\n";
 }
 
 void HtmlDocVisitor::visitPost(DocSection *s) 
@@ -985,25 +1044,18 @@ void HtmlDocVisitor::visitPost(DocHtmlDescData *)
 void HtmlDocVisitor::visitPre(DocHtmlTable *t)
 {
   if (m_hide) return;
-  bool hasBorder      = FALSE;
-  bool hasCellSpacing = FALSE;
-  bool hasCellPadding = FALSE;
 
   forceEndParagraph(t);
 
-  HtmlAttribListIterator li(t->attribs());
-  HtmlAttrib *att;
-  for (li.toFirst();(att=li.current());++li)
+  QString attrs = htmlAttribsToString(t->attribs());
+  if (attrs.isEmpty())
   {
-    if      (att->name=="border")      hasBorder=TRUE;
-    else if (att->name=="cellspacing") hasCellSpacing=TRUE;
-    else if (att->name=="cellpadding") hasCellPadding=TRUE;
+    m_t << "<table class=\"doxtable\">\n";
+  }
+  else
+  {
+    m_t << "<table " << htmlAttribsToString(t->attribs()) << ">\n";
   }
-  m_t << "<table" << htmlAttribsToString(t->attribs());
-  if (!hasBorder)      m_t << " border=\"1\"";
-  if (!hasCellSpacing) m_t << " cellspacing=\"3\"";
-  if (!hasCellPadding) m_t << " cellpadding=\"3\"";
-  m_t << ">\n";
 }
 
 void HtmlDocVisitor::visitPost(DocHtmlTable *t) 
@@ -1065,17 +1117,17 @@ void HtmlDocVisitor::visitPost(DocHtmlCaption *)
   m_t << "</caption>\n";
 }
 
-void HtmlDocVisitor::visitPre(DocInternal *)
+void HtmlDocVisitor::visitPre(DocInternal *i)
 {
   if (m_hide) return;
+  forceEndParagraph(i);
   m_t << "<p><b>" << theTranslator->trForInternalUseOnly() << "</b></p>" << endl;
-  m_t << "<p>" << endl;
 }
 
-void HtmlDocVisitor::visitPost(DocInternal *) 
+void HtmlDocVisitor::visitPost(DocInternal *i) 
 {
   if (m_hide) return;
-  m_t << "</p>" << endl;
+  forceStartParagraph(i);
 }
 
 void HtmlDocVisitor::visitPre(DocHRef *href)
@@ -1450,31 +1502,21 @@ void HtmlDocVisitor::filterQuotedCdataAttr(const char* str)
   }
 }
 
-void HtmlDocVisitor::startLink(const QString &ref,const QString &file,
-                               const QString &relPath,const QString &anchor,
-                               const QString &tooltip)
+void HtmlDocVisitor::startLink(const QCString &ref,const QCString &file,
+                               const QCString &relPath,const QCString &anchor,
+                               const QCString &tooltip)
 {
-  QCString *dest;
   if (!ref.isEmpty()) // link to entity imported via tag file
   {
     m_t << "<a class=\"elRef\" ";
-    m_t << "doxygen=\"" << ref << ":";
-    if ((dest=Doxygen::tagDestinationDict[ref])) m_t << *dest << "/";
-    m_t << "\" ";
+    m_t << externalLinkTarget() << externalRef(relPath,ref,FALSE);
   }
   else // local link
   {
     m_t << "<a class=\"el\" ";
   }
   m_t << "href=\"";
-  if (!ref.isEmpty())
-  {
-    if ((dest=Doxygen::tagDestinationDict[ref])) m_t << *dest << "/";
-  }
-  else
-  {
-    m_t << relPath;
-  }
+  m_t << externalRef(relPath,ref,TRUE);
   if (!file.isEmpty()) m_t << file << Doxygen::htmlFileExtension;
   if (!anchor.isEmpty()) m_t << "#" << anchor;
   m_t << "\"";
@@ -1500,42 +1542,42 @@ void HtmlDocVisitor::popEnabled()
   delete v;
 }
 
-void HtmlDocVisitor::writeDotFile(const QString &fileName,const QString &relPath,
-                                  const QString &context)
+void HtmlDocVisitor::writeDotFile(const QCString &fn,const QCString &relPath,
+                                  const QCString &context)
 {
-  QString baseName=fileName;
+  QCString baseName=fn;
   int i;
   if ((i=baseName.findRev('/'))!=-1)
   {
     baseName=baseName.right(baseName.length()-i-1);
   }
-  QString outDir = Config_getString("HTML_OUTPUT");
-  writeDotGraphFromFile(fileName,outDir,baseName,BITMAP);
-  QString mapName = baseName+".map";
-  QString mapFile = fileName+".map";
+  QCString outDir = Config_getString("HTML_OUTPUT");
+  writeDotGraphFromFile(fn,outDir,baseName,BITMAP);
+  QCString mapName = baseName+".map";
+  QCString mapFile = fn+".map";
   m_t << "<img src=\"" << relPath << baseName << "." 
-    << Config_getEnum("DOT_IMAGE_FORMAT") << "\" alt=\""
-    << baseName << "\" border=\"0\" usemap=\"#" << mapName << "\">" << endl;
-  QString imap = getDotImageMapFromFile(fileName,outDir,relPath.data(),context);
+      << Config_getEnum("DOT_IMAGE_FORMAT") << "\" alt=\""
+      << baseName << "\" border=\"0\" usemap=\"#" << mapName << "\">" << endl;
+  QCString imap = getDotImageMapFromFile(baseName,outDir,relPath,context);
   m_t << "<map name=\"" << mapName << "\" id=\"" << mapName << "\">" << imap << "</map>" << endl;
 }
 
-void HtmlDocVisitor::writeMscFile(const QString &fileName,const QString &relPath,
-                                  const QString &context)
+void HtmlDocVisitor::writeMscFile(const QCString &fileName,const QCString &relPath,
+                                  const QCString &context)
 {
-  QString baseName=fileName;
+  QCString baseName=fileName;
   int i;
   if ((i=baseName.findRev('/'))!=-1)
   {
     baseName=baseName.right(baseName.length()-i-1);
   }
-  QString outDir = Config_getString("HTML_OUTPUT");
+  QCString outDir = Config_getString("HTML_OUTPUT");
   writeMscGraphFromFile(fileName,outDir,baseName,MSC_BITMAP);
-  QString mapName = baseName+".map";
-  QString mapFile = fileName+".map";
+  QCString mapName = baseName+".map";
+  QCString mapFile = fileName+".map";
   m_t << "<img src=\"" << relPath << baseName << ".png\" alt=\""
     << baseName << "\" border=\"0\" usemap=\"#" << mapName << "\">" << endl;
-  QString imap = getMscImageMapFromFile(fileName,outDir,relPath.data(),context);
+  QCString imap = getMscImageMapFromFile(fileName,outDir,relPath,context);
   m_t << "<map name=\"" << mapName << "\" id=\"" << mapName << "\">" << imap << "</map>" << endl;
 }
 
