@@ -2,7 +2,7 @@
  *
  * $Id: htmlgen.h,v 1.51 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -25,6 +25,7 @@
 #define PREFRAG_END   "</pre></div>"
 
 class QFile;
+class FTextStream;
 
 class HtmlGenerator : public OutputGenerator
 {
@@ -35,6 +36,8 @@ class HtmlGenerator : public OutputGenerator
     static void writeStyleSheetFile(QFile &f);
     static void writeHeaderFile(QFile &f);
     static void writeFooterFile(QFile &f);
+    static void writeSearchPage();
+    static void writeTabData();
    
     void enable() 
     { if (genStack->top()) active=*genStack->top(); else active=TRUE; }
@@ -58,8 +61,8 @@ class HtmlGenerator : public OutputGenerator
     void startProjectNumber();
     void endProjectNumber();
     void writeStyleInfo(int part);
-    void startTitleHead(const char *) { startTitle(); }
-    void endTitleHead(const char *,const char *) { endTitle(); }
+    void startTitleHead(const char *);
+    void endTitleHead(const char *,const char *);
     void startTitle() { t << "<h1>"; }
     void endTitle() { t << "</h1>"; }
     
@@ -98,7 +101,9 @@ class HtmlGenerator : public OutputGenerator
 
     void startMemberSections();
     void endMemberSections();
-    void startMemberHeader();
+    void startHeaderSection();
+    void endHeaderSection();
+    void startMemberHeader(const char *);
     void endMemberHeader();
     void startMemberSubtitle();
     void endMemberSubtitle();
@@ -244,9 +249,9 @@ class HtmlGenerator : public OutputGenerator
     { t << "<a name=\"" << anchor << "\"></a>"; }
     void linkableSymbol(int,const char *,Definition *,Definition *) {}
 
-    static void writeSearchFooter(QTextStream &t,const QCString &relPath);
+    static void writeSearchFooter(FTextStream &t,const QCString &relPath);
     static void writeSearchData(const char *dir);
-    static void generateSectionImages();
+    //static void generateSectionImages();
 
   private:
     QCString lastTitle;
@@ -258,6 +263,7 @@ class HtmlGenerator : public OutputGenerator
     HtmlGenerator(const HtmlGenerator &g);
 
     int col;
+    int m_sectionCount;
 };
 
 #endif
