@@ -24,6 +24,7 @@
 #include <qdict.h>
 #include <qregexp.h>
 #include "qtextcodec.h"
+#include "sortdict.h"
 
 #include "htmlhelp.h"
 #include "config.h"
@@ -43,28 +44,15 @@ struct IndexField
   bool     reversed;
 };
 
-class IndexFieldList : public QList<IndexField>
+class IndexFieldSDict : public SDict<IndexField>
 {
   public:
+    IndexFieldSDict() : SDict<IndexField>(17) {}
+   ~IndexFieldSDict() {}
     int compareItems(GCI item1, GCI item2)
     {
       return stricmp(((IndexField *)item1)->name,((IndexField *)item2)->name);
     }
-   ~IndexFieldList() {}
-};
-
-class IndexFieldListIterator : public QListIterator<IndexField>
-{
-  public:
-    IndexFieldListIterator( const IndexFieldList &list) :
-       QListIterator<IndexField>(list) {}
-};
-
-class IndexFieldDict : public QDict<IndexField>
-{
-  public:
-    IndexFieldDict(int size) : QDict<IndexField>(size) {}
-   ~IndexFieldDict() {}
 };
 
 /*! A helper class for HtmlHelp that manages a two level index in 
@@ -78,24 +66,21 @@ class HtmlHelpIndex
     void addItem(const char *first,const char *second, 
                  const char *url, const char *anchor,
                  bool hasLink,bool reversed);
-    void writeFields(QTextStream &t);
+    void writeFields(FTextStream &t);
   private:
-    IndexFieldList *list;
-    IndexFieldDict *dict;   
+    IndexFieldSDict *dict;   
 };
 
 /*! Constructs a new HtmlHelp index */
 HtmlHelpIndex::HtmlHelpIndex()
 {
-  list = new IndexFieldList;
-  dict = new IndexFieldDict(10007);
-  list->setAutoDelete(TRUE);
+  dict = new IndexFieldSDict;
+  dict->setAutoDelete(TRUE);
 }
 
 /*! Destroys the HtmlHelp index */
 HtmlHelpIndex::~HtmlHelpIndex()
 {
-  delete list;
   delete dict;
 }
 
@@ -132,8 +117,7 @@ void HtmlHelpIndex::addItem(const char *level1,const char *level2,
     f->anchor   = anchor;
     f->link     = hasLink;
     f->reversed = reversed;
-    list->inSort(f);
-    dict->insert(key,f);
+    dict->append(key,f);
   }
 }
 
@@ -163,9 +147,10 @@ void HtmlHelpIndex::addItem(const char *level1,const char *level2,
  *      b1     -> link to url#anchor 
  *  </pre>
  */
-void HtmlHelpIndex::writeFields(QTextStream &t)
+void HtmlHelpIndex::writeFields(FTextStream &t)
 {
-  IndexFieldListIterator ifli(*list);
+  dict->sort();
+  IndexFieldSDict::Iterator ifli(*dict);
   IndexField *f;
   QCString lastLevel1;
   bool level2Started=FALSE;
@@ -320,7 +305,6 @@ void HtmlHelp::initialize()
   }
   /* Write the header of the contents file */
   cts.setDevice(cf);
-  cts.setEncoding(QTextStream::Latin1);
   cts << "<!DOCTYPE HTML PUBLIC \"-//IETF//DTD HTML//EN\">\n"
          "<HTML><HEAD></HEAD><BODY>\n"
          "<OBJECT type=\"text/site properties\">\n"
@@ -338,7 +322,6 @@ void HtmlHelp::initialize()
   }
   /* Write the header of the contents file */
   kts.setDevice(kf);
-  kts.setEncoding(QTextStream::Latin1);
   kts << "<!DOCTYPE HTML PUBLIC \"-//IETF//DTD HTML//EN\">\n"
          "<HTML><HEAD></HEAD><BODY>\n"
          "<OBJECT type=\"text/site properties\">\n"
@@ -461,12 +444,7 @@ void HtmlHelp::createProjectFile()
   QFile f(fName);
   if (f.open(IO_WriteOnly))
   {
-    QTextStream t(&f);
-#if QT_VERSION >= 200
-    t.setEncoding(QTextStream::Latin1);
-#endif
-
-   
+    FTextStream t(&f);
     
     QCString indexName="index"+Doxygen::htmlFileExtension;
     if (Config_getBool("GENERATE_TREEVIEW")) indexName="main"+Doxygen::htmlFileExtension;
@@ -506,9 +484,12 @@ void HtmlHelp::createProjectFile()
       s = indexFiles.next();
     }
     t << "tabs.css" << endl;
-    t << "tab_b.gif" << endl;
-    t << "tab_l.gif" << endl;
-    t << "tab_r.gif" << endl;
+    t << "tab_a.png" << endl;
+    t << "tab_b.png" << endl;
+    t << "tab_h.png" << endl;
+    t << "tab_s.png" << endl;
+    t << "nav_h.png" << endl;
+    t << "nav_f.png" << endl;
     if (Config_getBool("HTML_DYNAMIC_SECTIONS"))
     {
       t << "open.gif" << endl;
