@@ -2,7 +2,7 @@
  *
  * $Id: htmlhelp.h,v 1.7 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -22,8 +22,9 @@
 #define HTMLHELP_H
 
 #include "qtbc.h"
-#include <qtextstream.h>
 #include <qstrlist.h>
+#include "index.h"
+#include "ftextstream.h"
 
 class QFile;
 class HtmlHelpIndex;
@@ -32,7 +33,7 @@ class HtmlHelpIndex;
  *  These files can be used with the Microsoft HTML Help workshop
  *  to generate compressed HTML files (.chm).
  */
-class HtmlHelp 
+class HtmlHelp  : public IndexIntf
 {
     /*! used in imageNumber param of HTMLHelp::addContentsItem() function 
         to specify document icon in tree view.  
@@ -61,35 +62,39 @@ class HtmlHelp
       TOOL,             TOOL_NEW
     };
   public:
-    static HtmlHelp *getInstance();
+    //static HtmlHelp *getInstance();
+    HtmlHelp();
+    ~HtmlHelp();
     void initialize();
     void finalize();
-    int  incContentsDepth();
-    int  decContentsDepth();
-    /*! return the current depth of the contents tree */ 
-    int  contentsDepth() { return dc; }
-    // added imageNumber - KPW
+    void incContentsDepth();
+    void decContentsDepth();
     void addContentsItem(bool isDir,
                          const char *name, 
                          const char *ref = 0, 
+                         const char *file = 0,
                          const char *anchor = 0);
-    void addIndexItem(const char *level1, const char *level2, 
-                      const char *contRef, const char *memRef,
-                      const char *anchor);
+    //void addIndexItem(const char *level1, const char *level2, 
+    //                  const char *contRef, const char *memRef,
+    //                  const char *anchor,const MemberDef *md);
+    void addIndexItem(Definition *context,MemberDef *md,
+                      const char *anchor,const char *word);
     void addIndexFile(const char *name);
-
+    void addImageFile(const char *) {}
+    void addStyleSheetFile(const char *) {}
 
   private:
     void createProjectFile();
 
-    HtmlHelp();
     QFile *cf,*kf; 
-    QTextStream cts,kts;
+    FTextStream cts,kts;
     HtmlHelpIndex *index;
     int dc;
     QStrList indexFiles;
     QDict<void> indexFileDict;
     static HtmlHelp *theInstance;
+    QCString recode(const QCString &s);
+    void *m_fromUtf8;
 };
 
 #endif /* HTMLHELP_H */
