@@ -2,7 +2,7 @@
  *
  * $Id: instdox.cpp,v 1.16 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -21,7 +21,6 @@
 #include "qtbc.h"
 #include <qfile.h>
 #include <qfileinfo.h>
-#include <qtextstream.h>
 
 #include "instdox.h"
 #include "doxygen.h"
@@ -34,7 +33,7 @@ void writeInstallScript()
   QFile f(fileName);
   if (f.open(IO_WriteOnly))
   {
-    QTextStream t(&f);
+    FTextStream t(&f);
     t << "#!" << Config_getString("PERL_PATH") << endl << endl << "%subst = ( ";
     
     char *s=Config_getList("TAGFILES").first();
@@ -110,7 +109,7 @@ void writeInstallScript()
     t << "  }\n";
     t << "  elsif ( ! $quiet && $sub ne \"_doc\" && $sub ne \"_cgi\" )\n";
     t << "  {\n";
-    t << "    print \"Substituting $subst{$sub} for each occurence of tag file $sub\\n\"; \n";
+    t << "    print \"Substituting $subst{$sub} for each occurrence of tag file $sub\\n\"; \n";
     t << "  }\n";
     t << "}\n";
     t << "\n";
