@@ -2,7 +2,7 @@
  *
  * $Id: latexgen.cpp,v 1.58 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -92,7 +92,7 @@ void LatexGenerator::init()
   QCString latex_command = Config_getString("LATEX_CMD_NAME");
   QCString mkidx_command = Config_getString("MAKEINDEX_CMD_NAME");
   // end insertion by KONNO Akihisa <konno@researchers.jp> 2002-03-05
-  QTextStream t(&file);
+  FTextStream t(&file);
   if (!Config_getBool("USE_PDFLATEX")) // use plain old latex
   {
     t << "all: clean refman.dvi" << endl
@@ -166,7 +166,7 @@ void LatexGenerator::init()
   createSubDirs(d);
 }
 
-static void writeDefaultHeaderPart1(QTextStream &t)
+static void writeDefaultHeaderPart1(FTextStream &t)
 {
   // part 1
 
@@ -267,7 +267,7 @@ static void writeDefaultHeaderPart1(QTextStream &t)
 
 }
 
-static void writeDefaultHeaderPart2(QTextStream &t)
+static void writeDefaultHeaderPart2(FTextStream &t)
 {
   // part 2
   t << "}\\\\" << endl
@@ -275,7 +275,7 @@ static void writeDefaultHeaderPart2(QTextStream &t)
     << "{\\large ";
 }
 
-static void writeDefaultHeaderPart3(QTextStream &t)
+static void writeDefaultHeaderPart3(FTextStream &t)
 {
   // part 3
   t << " Doxygen " << versionString << "}\\\\" << endl
@@ -296,7 +296,7 @@ static void writeDefaultHeaderPart3(QTextStream &t)
   }
 }
 
-static void writeDefaultStyleSheetPart1(QTextStream &t)
+static void writeDefaultStyleSheetPart1(FTextStream &t)
 {
   // part 1
   t << "\\NeedsTeXFormat{LaTeX2e}\n"
@@ -329,13 +329,14 @@ static void writeDefaultStyleSheetPart1(QTextStream &t)
   t << "\\rfoot[\\fancyplain{}{\\bfseries\\scriptsize%\n  ";
 }
 
-static void writeDefaultStyleSheetPart2(QTextStream &t)
+static void writeDefaultStyleSheetPart2(FTextStream &t)
 {
   t << "\\lfoot[]{\\fancyplain{}{\\bfseries\\scriptsize%\n  ";
 }
 
-static void writeDefaultStyleSheetPart3(QTextStream &t)
+static void writeDefaultStyleSheetPart3(FTextStream &t)
 {
+  static bool latexSourceCode = Config_getBool("LATEX_SOURCE_CODE");
   t << "}}\n";
   t << "\\cfoot{}\n\n";
   t << "%---------- Internal commands used in this style file ----------------\n\n";
@@ -351,7 +352,7 @@ static void writeDefaultStyleSheetPart3(QTextStream &t)
        "    \\setlength{\\itemsep}{-4pt}%\n"
        "    \\renewcommand{\\makelabel}{\\entrylabel}%\n"
        "  }%\n"
-       "  \\item[#1:]%\n"
+       "  \\item[#1]%\n"
        "}{%\n"
        "  \\end{list}%\n"
        "}\n\n";
@@ -365,13 +366,27 @@ static void writeDefaultStyleSheetPart3(QTextStream &t)
        "  \\normalsize%\n"
        "}\n\n";
   t << "% Used by @code ... @endcode\n"
-       "\\newenvironment{DoxyCode}{%\n"
-       "  \\footnotesize%\n"
-       "  \\verbatim%\n"
-       "}{%\n"
-       "  \\endverbatim%\n"
-       "  \\normalsize%\n"
-       "}\n\n";
+       "\\newenvironment{DoxyCode}{%\n";
+  if (latexSourceCode)
+  {
+    t << "\n\n\\begin{footnotesize}\\begin{alltt}%" << endl;
+  }
+  else
+  {
+    t << "  \\footnotesize%\n"
+         "  \\verbatim%\n";
+  }
+  t << "}{%\n";
+  if (latexSourceCode)
+  {
+    t << "\\end{alltt}\\end{footnotesize}%" << endl; 
+  }
+  else
+  {
+    t << "  \\endverbatim%\n"
+         "  \\normalsize%\n";
+  }
+  t << "}\n\n";
   t << "% Used by @example, @include, @includelineno and @dontinclude\n"
        "\\newenvironment{DoxyCodeInclude}{%\n"
        "  \\DoxyCode%\n"
@@ -504,9 +519,8 @@ static void writeDefaultStyleSheetPart3(QTextStream &t)
        "}\n\n";
   t << "% Used by @internal\n"
        "\\newenvironment{DoxyInternal}[1]{%\n"
-       "  \\begin{DoxyDesc}{#1}%\n"
+       "  \\paragraph*{#1}%\n"
        "}{%\n"
-       "  \\end{DoxyDesc}%\n"
        "}\n\n";
   t << "% Used by @par and @paragraph\n"
        "\\newenvironment{DoxyParagraph}[1]{%\n"
@@ -530,6 +544,11 @@ static void writeDefaultStyleSheetPart3(QTextStream &t)
        "    \\end{description}%\n"
        "  \\end{DoxyDesc}%\n"
        "}\n\n";
+  t << "% is used for parameters within a detailed function description\n"
+       "\\newenvironment{DoxyParamCaption}{%\n"
+       "  \\renewcommand{\\item}[2][]{##1 {\\em ##2}}%\n"
+       "  }{%\n"
+       "}\n\n";
   t << "% Used by return value lists\n"
        "\\newenvironment{DoxyRetVals}[1]{%\n"
        "  \\begin{DoxyDesc}{#1}%\n"
@@ -629,7 +648,7 @@ static void writeDefaultStyleSheetPart3(QTextStream &t)
 
 void LatexGenerator::writeHeaderFile(QFile &f)
 {
-  QTextStream t(&f);
+  FTextStream t(&f);
   writeDefaultHeaderPart1(t);
   t << "Your title here";
   writeDefaultHeaderPart2(t);
@@ -639,8 +658,7 @@ void LatexGenerator::writeHeaderFile(QFile &f)
 
 void LatexGenerator::writeStyleSheetFile(QFile &f)
 {
-  QTextStream t(&f);
-  t.setEncoding(QTextStream::UnicodeUTF8);
+  FTextStream t(&f);
 
   writeDefaultStyleSheetPart1(t);
   QCString &projectName = Config_getString("PROJECT_NAME");
@@ -648,12 +666,12 @@ void LatexGenerator::writeStyleSheetFile(QFile &f)
   t << theTranslator->trGeneratedAt( dateToString(TRUE), projectName );
   t << " doxygen";
   //t << " " << theTranslator->trWrittenBy() << " ";
-  //t << "Dimitri van Heesch \\copyright~1997-2008";
+  //t << "Dimitri van Heesch \\copyright~1997-2010";
   writeDefaultStyleSheetPart2(t);
   t << theTranslator->trGeneratedAt( dateToString(TRUE), projectName );
   t << " doxygen";
   //t << " << theTranslator->trWrittenBy() << " ";
-  //t << "Dimitri van Heesch \\copyright~1997-2008";
+  //t << "Dimitri van Heesch \\copyright~1997-2010";
   writeDefaultStyleSheetPart3(t);
 }
 
@@ -856,7 +874,7 @@ void LatexGenerator::startIndexSection(IndexSections is)
 
 void LatexGenerator::endIndexSection(IndexSections is)
 {
-  static bool compactLatex = Config_getBool("COMPACT_LATEX");
+  //static bool compactLatex = Config_getBool("COMPACT_LATEX");
   static bool sourceBrowser = Config_getBool("SOURCE_BROWSER");
   static QCString latexHeader = Config_getString("LATEX_HEADER");
   switch (is)
@@ -915,7 +933,8 @@ void LatexGenerator::endIndexSection(IndexSections is)
         {
           if (!gd->isReference())
           {
-            if (compactLatex) t << "\\input"; else t << "\\include";
+            //if (compactLatex) t << "\\input"; else t << "\\include";
+            t << "\\input"; 
             t << "{" << gd->getOutputFileBase() << "}\n";
           }
         }
@@ -938,7 +957,8 @@ void LatexGenerator::endIndexSection(IndexSections is)
         {
           if (dd->isLinkableInProject())
           {
-            if (compactLatex) t << "\\input"; else t << "\\include";
+            //if (compactLatex) t << "\\input"; else t << "\\include";
+            t << "\\input"; 
             t << "{" << dd->getOutputFileBase() << "}\n";
           }
         }
@@ -961,7 +981,8 @@ void LatexGenerator::endIndexSection(IndexSections is)
         {
           if (nd->isLinkableInProject())
           {
-            if (compactLatex) t << "\\input"; else t << "\\include";
+            //if (compactLatex) t << "\\input"; else t << "\\include";
+            t << "\\input"; 
             t << "{" << nd->getOutputFileBase() << "}\n";
           }
           ++nli;
@@ -985,7 +1006,8 @@ void LatexGenerator::endIndexSection(IndexSections is)
         {
           if (cd->isLinkableInProject() && cd->templateMaster()==0)
           {
-            if (compactLatex) t << "\\input"; else t << "\\include";
+            //if (compactLatex) t << "\\input"; else t << "\\include";
+            t << "\\input"; 
             t << "{" << cd->getOutputFileBase() << "}\n";
           } 
         }
@@ -1007,17 +1029,20 @@ void LatexGenerator::endIndexSection(IndexSections is)
                 t << "}\n\\input{" << fd->getOutputFileBase() << "}\n";
                 if (sourceBrowser && m_prettyCode && fd->generateSourceFile())
                 {
-                  t << "\\include{" << fd->getSourceFileBase() << "}\n";
+                  //t << "\\include{" << fd->getSourceFileBase() << "}\n";
+                  t << "\\input{" << fd->getSourceFileBase() << "}\n";
                 }
                 isFirst=FALSE;
               }
               else
               {
-                if (compactLatex) t << "\\input" ; else t << "\\include";
+                //if (compactLatex) t << "\\input" ; else t << "\\include";
+                t << "\\input" ; 
                 t << "{" << fd->getOutputFileBase() << "}\n";
                 if (sourceBrowser && m_prettyCode && fd->generateSourceFile())
                 {
-                  t << "\\include{" << fd->getSourceFileBase() << "}\n";
+                  //t << "\\include{" << fd->getSourceFileBase() << "}\n";
+                  t << "\\input{" << fd->getSourceFileBase() << "}\n";
                 }
               }
             }
@@ -1038,7 +1063,8 @@ void LatexGenerator::endIndexSection(IndexSections is)
         }
         for (++pdi;(pd=pdi.current());++pdi)
         {
-          if (compactLatex) t << "\\input" ; else t << "\\include";
+          //if (compactLatex) t << "\\input" ; else t << "\\include";
+          t << "\\input"; 
           t << "{" << pd->getOutputFileBase() << "}\n";
         }
       }
@@ -1075,10 +1101,12 @@ void LatexGenerator::endIndexSection(IndexSections is)
   }
 }
 
-void LatexGenerator::writePageLink(const char *name, bool first)
+void LatexGenerator::writePageLink(const char *name, bool /*first*/)
 {
-  bool &compactLatex = Config_getBool("COMPACT_LATEX");
-  if (compactLatex || first) t << "\\input" ; else t << "\\include";
+  //bool &compactLatex = Config_getBool("COMPACT_LATEX");
+  // next is remove for bug615957
+  //if (compactLatex || first) t << "\\input" ; else t << "\\include";
+  t << "\\input" ; 
   t << "{" << name << "}\n";
 }
 
@@ -1100,14 +1128,14 @@ void LatexGenerator::writeStyleInfo(int part)
       break;
     case 2:
       {
-        //t << " Dimitri van Heesch \\copyright~1997-2008";
+        //t << " Dimitri van Heesch \\copyright~1997-2010";
         t << "}]{}\n";
         writeDefaultStyleSheetPart2(t);
       }
       break;
     case 4:
       {
-        //t << " Dimitri van Heesch \\copyright~1997-2008";
+        //t << " Dimitri van Heesch \\copyright~1997-2010";
         writeDefaultStyleSheetPart3(t);
         endPlainFile();
       }
@@ -1127,6 +1155,7 @@ void LatexGenerator::startParagraph()
 
 void LatexGenerator::endParagraph()
 {
+  t << endl << endl;
 }
 
 void LatexGenerator::writeString(const char *text)
@@ -1380,7 +1409,7 @@ void LatexGenerator::endGroupHeader()
   t << "}" << endl;
 }
 
-void LatexGenerator::startMemberHeader()
+void LatexGenerator::startMemberHeader(const char *)
 {
   if (Config_getBool("COMPACT_LATEX")) 
   {
@@ -1572,7 +1601,6 @@ void LatexGenerator::endSection(const char *lab,SectionInfo::SectionType)
 }
 
 
-//void LatexGenerator::docifyStatic(QTextStream &t,const char *str)
 void LatexGenerator::docify(const char *str)
 {
   filterLatexString(t,str,insideTabbing,FALSE);
@@ -1580,38 +1608,18 @@ void LatexGenerator::docify(const char *str)
 
 void LatexGenerator::codify(const char *str)
 {
-  static bool isJapanese  = theTranslator->idLanguage()=="japanese" || 
-                            theTranslator->idLanguage()=="japanese-en";
-
   if (str)
   { 
     const char *p=str;
     char c;
-    char cs[2];
-    cs[1]='\0';
+    char cs[5];
     int spacesToNextTabStop;
     static int tabSize = Config_getInt("TAB_SIZE");
     while (*p)
     {
-      static bool MultiByte = FALSE;
+      //static bool MultiByte = FALSE;
       c=*p++;
 
-      if( isJapanese )
-      {
-        if ( MultiByte )
-        {
-          t << (char)c;
-          MultiByte = FALSE;
-          continue;
-        }
-        if ((uchar)c>=0x80) // char in range [0x80..0xff]
-        {
-          t << (char)c;
-          MultiByte = TRUE;
-          continue;
-        }
-      }
-
       switch(c)
       {
         case 0x0c: break; // remove ^L
@@ -1621,14 +1629,34 @@ void LatexGenerator::codify(const char *str)
                    col+=spacesToNextTabStop;
                    break; 
         case '\n': t << '\n'; col=0;                    break;
-        default:   if (m_prettyCode)
+        default:   cs[0]=c;
+                   cs[1]=0;
+                   int bytes=1;
+                   if (c<0) // multibyte utf-8 character
+                   {
+                     bytes++;   // 1xxx.xxxx: >=2 byte character
+                     cs[1]=*p;
+                     cs[2]=0;
+                     if (((uchar)c&0xE0)==0xE0)
+                     {
+                       bytes++; // 111x.xxxx: >=3 byte character
+                       cs[2]=*(p+1);
+                       cs[3]=0;
+                     }
+                     if (((uchar)c&0xF0)==0xF0)
+                     {
+                       bytes++; // 1111.xxxx: 4 byte character
+                       cs[2]=*(p+2);
+                       cs[4]=0;
+                     }
+                   }
+                   if (m_prettyCode)
                    {
-                     cs[0]=c; 
                      filterLatexString(t,cs,insideTabbing,TRUE);
                    }
                    else
                    {
-                     t << c;
+                     t << cs;
                    }
                    if (col>=80)
                    {
@@ -1637,8 +1665,9 @@ void LatexGenerator::codify(const char *str)
                    }
                    else
                    {
-                     col++;                    
+                     col++;
                    }
+                   p+=(bytes-1); // skip to next character
                    break;
       }
     }
@@ -1811,11 +1840,12 @@ void LatexGenerator::endMemberGroup(bool hasHeader)
 
 void LatexGenerator::startDotGraph() 
 {
+  newParagraph();
 }
 
 void LatexGenerator::endDotGraph(const DotClassGraph &g) 
 {
-  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
+  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),fileName,relPath);
 }
 
 void LatexGenerator::startInclDepGraph() 
@@ -1824,7 +1854,7 @@ void LatexGenerator::startInclDepGraph()
 
 void LatexGenerator::endInclDepGraph(const DotInclDepGraph &g) 
 {
-  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
+  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),fileName,relPath);
 }
 
 void LatexGenerator::startGroupCollaboration() 
@@ -1833,7 +1863,7 @@ void LatexGenerator::startGroupCollaboration()
 
 void LatexGenerator::endGroupCollaboration(const DotGroupCollaboration &g) 
 {
-  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
+  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),fileName,relPath);
 }
 
 void LatexGenerator::startCallGraph() 
@@ -1842,7 +1872,7 @@ void LatexGenerator::startCallGraph()
 
 void LatexGenerator::endCallGraph(const DotCallGraph &g) 
 {
-  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
+  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),fileName,relPath);
 }
 
 void LatexGenerator::startDirDepGraph() 
@@ -1851,7 +1881,7 @@ void LatexGenerator::startDirDepGraph()
 
 void LatexGenerator::endDirDepGraph(const DotDirDeps &g) 
 {
-  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
+  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),fileName,relPath);
 }
 
 void LatexGenerator::startDescription() 
@@ -1916,14 +1946,50 @@ void LatexGenerator::endParamList()
   t << "\\end{Desc}" << endl;
 }
 
-void LatexGenerator::startParameterType(bool first,const char *key)
+void LatexGenerator::startParameterList(bool openBracket)
 {
-  if (!first)
+  /* start of ParameterType ParameterName list */
+  if (openBracket) t << "(";
+  t << endl << "\\begin{DoxyParamCaption}" << endl;
+}
+
+void LatexGenerator::endParameterList()
+{
+}
+
+
+void LatexGenerator::startParameterType(bool /*first*/,const char *key)
+{
+  t << "\\item[{";
+  t << key;
+//  if (!first)
+//  {
+//    t << "\\/ " << key << " ";
+//  }
+}
+
+void LatexGenerator::endParameterType()
+{
+  t << "}]";
+}
+
+void LatexGenerator::startParameterName(bool /*oneArgOnly*/)
+{
+  t << "{";
+}
+
+void LatexGenerator::endParameterName(bool last,bool /* emptyList */,bool closeBracket)
+{
+  t << "}" << endl;
+
+  if (last)
   {
-    t << "\\/ " << key << " ";
+    t << "\\end{DoxyParamCaption}" << endl;
+    if (closeBracket) t << ")";
   }
 }
 
+
 void LatexGenerator::printDoc(DocNode *n,const char *langExt)
 {
   LatexDocVisitor *visitor = new LatexDocVisitor(t,*this,langExt,insideTabbing);
@@ -2013,27 +2079,27 @@ void LatexGenerator::escapeMakeIndexChars(const char *s)
 
 void LatexGenerator::startCodeFragment()
 {
-  if (m_prettyCode)
-  {
-    t << endl << endl;
-    t << "\\begin{footnotesize}\\begin{alltt}\n";
-  }
-  else
-  {
+  //if (m_prettyCode)
+  //{
+  //  t << endl << endl;
+  //  t << "\\begin{footnotesize}\\begin{alltt}\n";
+  //}
+  //else
+  //{
     t << "\n\\begin{DoxyCode}\n";
-  }
+  //}
 }
 
 void LatexGenerator::endCodeFragment()
 {
-  if (m_prettyCode)
-  {
-    t << "\\end{alltt}\\end{footnotesize}" << endl; 
-  }
-  else
-  {
+  //if (m_prettyCode)
+  //{
+  //  t << "\\end{alltt}\\end{footnotesize}" << endl; 
+  //}
+  //else
+  //{
     t << "\\end{DoxyCode}\n";
-  }
+  //}
 }
 
 void LatexGenerator::writeLineNumber(const char *ref,const char *fileName,const char *anchor,int l)
