@@ -1,9 +1,9 @@
 /******************************************************************************
  *
- * 
+ * $Id: $
  *
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -21,16 +21,16 @@
 
 #include "docvisitor.h"
 #include <qstack.h>
+#include <qcstring.h>
 
-class QTextStream;
-class BaseCodeDocInterface;
-class QString;
+class FTextStream;
+class CodeOutputInterface;
 
 /*! @brief Concrete visitor implementation for LaTeX output. */
 class ManDocVisitor : public DocVisitor
 {
   public:
-    ManDocVisitor(QTextStream &t,BaseCodeDocInterface &ci);
+    ManDocVisitor(FTextStream &t,CodeOutputInterface &ci,const char *langExt);
     
     //--------------------------------------
     // visitor functions for leaf nodes
@@ -50,6 +50,7 @@ class ManDocVisitor : public DocVisitor
     void visit(DocIncOperator *);
     void visit(DocFormula *);
     void visit(DocIndexEntry *);
+    void visit(DocSimpleSectSep *);
 
     //--------------------------------------
     // visitor functions for compound nodes
@@ -141,13 +142,14 @@ class ManDocVisitor : public DocVisitor
     // state variables
     //--------------------------------------
 
-    QTextStream &m_t;
-    BaseCodeDocInterface &m_ci;
+    FTextStream &m_t;
+    CodeOutputInterface &m_ci;
     bool m_insidePre;
     bool m_hide;
     bool m_firstCol;
     int  m_indent;
     QStack<bool> m_enabled;
+    QCString m_langExt;
 };
 
 #endif
