@@ -395,7 +395,7 @@ void marshalEntry(StorageIntf *s,Entry *e)
   marshalInt(s,e->inbodyLine);
   marshalQCString(s,e->inbodyFile);
   marshalQCString(s,e->relates);
-  marshalBool(s,e->relatesDup);
+  marshalInt(s,e->relatesType);
   marshalQCString(s,e->read);
   marshalQCString(s,e->write);
   marshalQCString(s,e->inside);
@@ -410,7 +410,7 @@ void marshalEntry(StorageIntf *s,Entry *e)
   marshalQCString(s,e->fileName);
   marshalInt(s,e->startLine);
   marshalItemInfoList(s,e->sli);
-  marshalBool(s,e->objc);
+  marshalInt(s,(int)e->lang);
   marshalBool(s,e->hidden);
   marshalBool(s,e->artificial);
   marshalInt(s,(int)e->groupDocType);
@@ -788,7 +788,7 @@ Entry * unmarshalEntry(StorageIntf *s)
   e->inbodyLine       = unmarshalInt(s);
   e->inbodyFile       = unmarshalQCString(s);
   e->relates          = unmarshalQCString(s);
-  e->relatesDup       = unmarshalBool(s);
+  e->relatesType      = (RelatesType)unmarshalInt(s);
   e->read             = unmarshalQCString(s);
   e->write            = unmarshalQCString(s);
   e->inside           = unmarshalQCString(s);
@@ -806,7 +806,7 @@ Entry * unmarshalEntry(StorageIntf *s)
   e->fileName         = unmarshalQCString(s);
   e->startLine        = unmarshalInt(s);
   e->sli              = unmarshalItemInfoList(s);
-  e->objc             = unmarshalBool(s);
+  e->lang             = (SrcLangExt)unmarshalInt(s);
   e->hidden           = unmarshalBool(s);
   e->artificial       = unmarshalBool(s);
   e->groupDocType     = (Entry::GroupDocType)unmarshalInt(s);
