@@ -2,7 +2,7 @@
  *
  * $Id: message.cpp,v 1.9 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -22,6 +22,7 @@
 #include "util.h"
 #include "debug.h"
 #include "doxygen.h"
+#include "portable.h"
 
 static QCString outputFormat;
 //static int warnFormatOrder; // 1 = $file,$line,$text
@@ -88,7 +89,7 @@ void initWarningFormat()
 
   if (!Config_getString("WARN_LOGFILE").isEmpty())
   {
-    warnFile = fopen(Config_getString("WARN_LOGFILE"),"w");
+    warnFile = portable_fopen(Config_getString("WARN_LOGFILE"),"w");
   }
   if (!warnFile) // point it to something valid, because warn() relies on it
   {
@@ -161,16 +162,6 @@ void warn(const char *file,int line,const char *fmt, ...)
   va_end(args); 
 }
 
-void warn_cont(const char *fmt, ...)
-{
-  if (!Config_getBool("WARNINGS"))
-    return;
-  va_list args;
-  va_start(args, fmt);
-  vfprintf(warnFile, fmt, args);
-  va_end(args); 
-}
-  
 void warn_undoc(const char *file,int line,const char *fmt, ...)
 {
   va_list args;
