@@ -2,7 +2,7 @@
  *
  * $Id: msc.cpp,v 1.14 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -27,12 +27,12 @@
 static const int maxCmdLine = 40960;
 
 static bool convertMapFile(QTextStream &t,const char *mapName,const QCString relPath,
-                           const QString &context)
+                           const QCString &context)
 {
   QFile f(mapName);
   if (!f.open(IO_ReadOnly))
   {
-    err("Error opening map file %s for inclusion in the docs!\n"
+    err("error: failed to open map file %s for inclusion in the docs!\n"
         "If you installed Graphviz/dot after a previous failing run, \n"
         "try deleting the output directory and rerun doxygen.\n",mapName);
     return FALSE;
@@ -68,13 +68,9 @@ static bool convertMapFile(QTextStream &t,const char *mapName,const QCString rel
       if ( isRef )
       {
         // handle doxygen \ref tag URL reference
-        QCString *dest;
         DocRef *df = new DocRef( (DocNode*) 0, url, context );
-        if (!df->ref().isEmpty())
-        {
-          if ((dest=Doxygen::tagDestinationDict[df->ref()])) t << *dest << "/";
-        }
-        if (!df->file().isEmpty()) t << relPath << df->file() << Doxygen::htmlFileExtension;
+        t << externalRef(relPath,df->ref(),TRUE);
+        if (!df->file().isEmpty()) t << df->file() << Doxygen::htmlFileExtension;
         if (!df->anchor().isEmpty()) t << "#" << df->anchor();
       }
       else
@@ -121,29 +117,34 @@ void writeMscGraphFromFile(const char *inFile,const char *outDir,
   mscArgs+=extension+"\"";
   int exitCode;
   //printf("*** running: %s %s\n",mscExe.data(),mscArgs.data());
+  portable_sysTimerStart();
   if ((exitCode=portable_system(mscExe,mscArgs,FALSE))!=0)
   {
+    portable_sysTimerStop();
     goto error;
   }
+  portable_sysTimerStop();
   if ( (format==MSC_EPS) && (Config_getBool("USE_PDFLATEX")) )
   {
     QCString epstopdfArgs(maxCmdLine);
     epstopdfArgs.sprintf("\"%s.eps\" --outfile=\"%s.pdf\"",
                          outFile,outFile);
+    portable_sysTimerStart();
     if (portable_system("epstopdf",epstopdfArgs)!=0)
     {
-      err("Error: Problems running epstopdf. Check your TeX installation!\n");
+      err("error: Problems running epstopdf. Check your TeX installation!\n");
     }
+    portable_sysTimerStop();
   }
 
 error:
   QDir::setCurrent(oldDir);
 }
 
-QString getMscImageMapFromFile(const QString& inFile, const QString& outDir,
-                               const QCString& relPath,const QString& context)
+QCString getMscImageMapFromFile(const QCString& inFile, const QCString& outDir,
+                                const QCString& relPath,const QCString& context)
 {
-  QString outFile = inFile + ".map";
+  QCString outFile = inFile + ".map";
 
   // chdir to the output dir, so dot can find the font file.
   QCString oldDir = convertToQCString(QDir::currentDirPath());
@@ -157,11 +158,14 @@ QString getMscImageMapFromFile(const QString& inFile, const QString& outDir,
   mscArgs+=outFile + "\"";
 
   int exitCode;
+  portable_sysTimerStart();
   if ((exitCode=portable_system(mscExe,mscArgs,FALSE))!=0)
   {
+    portable_sysTimerStop();
     QDir::setCurrent(oldDir);
     return "";
   }
+  portable_sysTimerStop();
   
   QString result;
   QTextOStream tmpout(&result);
@@ -169,7 +173,7 @@ QString getMscImageMapFromFile(const QString& inFile, const QString& outDir,
   QDir().remove(outFile);
 
   QDir::setCurrent(oldDir);
-  return result;
+  return result.data();
 }
 
 
