@@ -2,7 +2,7 @@
  *
  * $Id: outputlist.h,v 1.47 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -97,14 +97,18 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startTitle); }
     void endTitle() 
     { forall(&OutputGenerator::endTitle); }
-    void newParagraph() 
-    { forall(&OutputGenerator::newParagraph); }
+    //void newParagraph() 
+    //{ forall(&OutputGenerator::newParagraph); }
     void startParagraph() 
     { forall(&OutputGenerator::startParagraph); }
     void endParagraph() 
     { forall(&OutputGenerator::endParagraph); }
     void writeString(const char *text) 
     { forall(&OutputGenerator::writeString,text); }
+    void startIndexListItem() 
+    { forall(&OutputGenerator::startIndexListItem); }
+    void endIndexListItem() 
+    { forall(&OutputGenerator::endIndexListItem); }
     void startIndexList() 
     { forall(&OutputGenerator::startIndexList); }
     void endIndexList() 
@@ -157,14 +161,22 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startGroupHeader); }
     void endGroupHeader()
     { forall(&OutputGenerator::endGroupHeader); }
-    void writeListItem() 
-    { forall(&OutputGenerator::writeListItem); }
+    //void writeListItem() 
+    //{ forall(&OutputGenerator::writeListItem); }
+    void startItemListItem() 
+    { forall(&OutputGenerator::startItemListItem); }
+    void endItemListItem() 
+    { forall(&OutputGenerator::endItemListItem); }
     void startMemberSections()
     { forall(&OutputGenerator::startMemberSections); }
     void endMemberSections()
     { forall(&OutputGenerator::endMemberSections); }
-    void startMemberHeader()
-    { forall(&OutputGenerator::startMemberHeader); }
+    void startHeaderSection()
+    { forall(&OutputGenerator::startHeaderSection); }
+    void endHeaderSection()
+    { forall(&OutputGenerator::endHeaderSection); }
+    void startMemberHeader(const char *anchor)
+    { forall(&OutputGenerator::startMemberHeader,anchor); }
     void endMemberHeader()
     { forall(&OutputGenerator::endMemberHeader); }
     void startMemberSubtitle()
@@ -251,6 +263,10 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startDescItem); }
     void endDescItem() 
     { forall(&OutputGenerator::endDescItem); }
+    void startDescForItem() 
+    { forall(&OutputGenerator::startDescForItem); }
+    void endDescForItem() 
+    { forall(&OutputGenerator::endDescForItem); }
     void startSubsection() 
     { forall(&OutputGenerator::startSubsection); }
     void endSubsection() 
@@ -267,8 +283,8 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startSmall); }
     void endSmall() 
     { forall(&OutputGenerator::endSmall); }
-    void lineBreak() 
-    { forall(&OutputGenerator::lineBreak); }
+    void lineBreak(const char *style=0) 
+    { forall(&OutputGenerator::lineBreak,style); }
     void startBold() 
     { forall(&OutputGenerator::startBold); }
     void endBold() 
@@ -286,8 +302,8 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startParamList,t,title); }
     void endParamList() 
     { forall(&OutputGenerator::endParamList); }
-    void writeDescItem() 
-    { forall(&OutputGenerator::writeDescItem); }
+    //void writeDescItem() 
+    //{ forall(&OutputGenerator::writeDescItem); }
     void startIndent() 
     { forall(&OutputGenerator::startIndent); }
     void endIndent() 
