@@ -6,6 +6,7 @@
 #include "outputlist.h"
 #include "doxygen.h"
 #include "language.h"
+#include <qregexp.h>
 
 
 PageDef::PageDef(const char *f,int l,const char *n,
@@ -70,12 +71,9 @@ void PageDef::writeDocumentation(OutputList &ol)
 {
   //outputList->disable(OutputGenerator::Man);
   QCString pageName;
-  if (Config_getBool("CASE_SENSE_NAMES"))
-    pageName=name();
-  else
-    pageName=name().lower();
+  pageName=escapeCharsInString(name(),FALSE,TRUE);
 
-  startFile(ol,pageName,pageName,title(),HLI_Pages,TRUE);
+  startFile(ol,getOutputFileBase(),pageName,title(),HLI_Pages,TRUE);
 
   ol.pushGeneratorState();
   //1.{ 
@@ -98,7 +96,6 @@ void PageDef::writeDocumentation(OutputList &ol)
   }
 
   ol.endQuickIndices();
-  ol.startContents();
 
   // save old generator state and write title only to Man generator
   ol.pushGeneratorState();
@@ -116,15 +113,18 @@ void PageDef::writeDocumentation(OutputList &ol)
   ol.disable(OutputGenerator::RTF);
   SectionInfo *si=0;
   if (!title().isEmpty() && !name().isEmpty() &&
-      (si=Doxygen::sectionDict.find(pageName))!=0)
+      (si=Doxygen::sectionDict.find(name()))!=0)
   {
-    ol.startSection(si->label,si->title,si->type);
+    //ol.startSection(si->label,si->title,si->type);
+    startTitle(ol,getOutputFileBase(),this);
     ol.parseDoc(docFile(),docLine(),this,0,si->title,TRUE,FALSE,0,TRUE,FALSE);
     //stringToSearchIndex(getOutputFileBase(),
     //                    theTranslator->trPage(TRUE,TRUE)+" "+si->title,
     //                    si->title);
-    ol.endSection(si->label,si->type);
+    //ol.endSection(si->label,si->type);
+    endTitle(ol,getOutputFileBase(),name());
   }
+  ol.startContents();
   ol.popGeneratorState();
   //2.}
 
@@ -158,12 +158,15 @@ void PageDef::writeDocumentation(OutputList &ol)
       Doxygen::tagFile << "  </compound>" << endl;
     }
   }
+
+  Doxygen::indexList.addIndexItem(this,0,0,filterTitle(title()));
 }
 
 void PageDef::writePageDocumentation(OutputList &ol)
 {
   ol.startTextBlock();
-  ol.parseDoc(docFile(),   // fileName
+  ol.parseDoc(
+      docFile(),           // fileName
       docLine(),           // startLine
       this,                // context
       0,                   // memberdef
