@@ -3,7 +3,7 @@
  *
  *
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  * Authors: Dimitri van Heesch, Miguel Lobo.
  *
  * Permission to use, copy, modify, and distribute this software and its
@@ -29,7 +29,7 @@
 #include <qstack.h>
 #include <qdict.h>
 #include <qfile.h>
-#include <qtextstream.h>
+#include "ftextstream.h"
 
 #define PERLOUTPUT_MAX_INDENTATION 40
 
@@ -37,15 +37,14 @@ class PerlModOutputStream
 {
 public:
 
-  QString m_s;
-  QTextStream *m_t;
+  QCString m_s;
+  FTextStream *m_t;
 
-  PerlModOutputStream(QTextStream *t = 0) : m_t(t) { }
+  PerlModOutputStream(FTextStream *t = 0) : m_t(t) { }
 
   void add(char c);
   void add(const char *s);
   void add(QCString &s);
-  void add(QString &s);
   void add(int n);
   void add(unsigned int n);
 };
@@ -74,14 +73,6 @@ void PerlModOutputStream::add(QCString &s)
     m_s += s;
 }
 
-void PerlModOutputStream::add(QString &s)
-{
-  if (m_t != 0)
-    (*m_t) << s;
-  else
-    m_s += s;
-}
-
 void PerlModOutputStream::add(int n)
 {
   if (m_t != 0)
@@ -115,7 +106,7 @@ public:
   inline void setPerlModOutputStream(PerlModOutputStream *os) { m_stream = os; }
 
   inline PerlModOutput &openSave() { iopenSave(); return *this; }
-  inline PerlModOutput &closeSave(QString &s) { icloseSave(s); return *this; }
+  inline PerlModOutput &closeSave(QCString &s) { icloseSave(s); return *this; }
 
   inline PerlModOutput &continueBlock()
   {
@@ -130,7 +121,6 @@ public:
   inline PerlModOutput &add(char c) { m_stream->add(c); return *this; }
   inline PerlModOutput &add(const char *s) { m_stream->add(s); return *this; }
   inline PerlModOutput &add(QCString &s) { m_stream->add(s); return *this; }
-  inline PerlModOutput &add(QString &s) { m_stream->add(s); return *this; }
   inline PerlModOutput &add(int n) { m_stream->add(n); return *this; }
   inline PerlModOutput &add(unsigned int n) { m_stream->add(n); return *this; }
 
@@ -169,7 +159,7 @@ public:
 protected:
   
   void iopenSave();
-  void icloseSave(QString &);
+  void icloseSave(QCString &);
   
   void incIndent();
   void decIndent();
@@ -198,7 +188,7 @@ void PerlModOutput::iopenSave()
   m_stream = new PerlModOutputStream();
 }
 
-void PerlModOutput::icloseSave(QString &s)
+void PerlModOutput::icloseSave(QCString &s)
 {
   s = m_stream->m_s;
   delete m_stream;
@@ -389,8 +379,8 @@ private:
   // helper functions
   //--------------------------------------
 
-  void addLink(const QString &ref, const QString &file,
-	       const QString &anchor);
+  void addLink(const QCString &ref, const QCString &file,
+	       const QCString &anchor);
    
   void enterText();
   void leaveText();
@@ -410,7 +400,7 @@ private:
   PerlModOutput &m_output;
   bool m_textmode;
   bool m_textblockstart;
-  QString m_other;
+  QCString m_other;
 };
 
 PerlModDocVisitor::PerlModDocVisitor(PerlModOutput &output)
@@ -426,9 +416,9 @@ void PerlModDocVisitor::finish()
     .add(m_other);
 }
 
-void PerlModDocVisitor::addLink(const QString &,const QString &file,const QString &anchor)
+void PerlModDocVisitor::addLink(const QCString &,const QCString &file,const QCString &anchor)
 {
-  QString link = file;
+  QCString link = file;
   if (!anchor.isEmpty())
     (link += "_1") += anchor;
   m_output.addFieldQuotedString("link", link);
@@ -473,6 +463,7 @@ void PerlModDocVisitor::singleItem(const char *name)
 
 void PerlModDocVisitor::openSubBlock(const char *s)
 {
+  leaveText();
   m_output.openList(s);
   m_textblockstart = true;
 }
@@ -498,7 +489,7 @@ void PerlModDocVisitor::closeOther()
   // Using a secondary text stream will corrupt the perl file. Instead of
   // printing doc => [ data => [] ], it will print doc => [] data => [].
   /*
-  QString other;
+  QCString other;
   leaveText();
   m_output.closeSave(other);
   m_other += other;
@@ -533,53 +524,59 @@ void PerlModDocVisitor::visit(DocSymbol *sy)
   const char *symbol = 0;
   switch(sy->symbol())
   {
-  case DocSymbol::At:      c = '@'; break;
-  case DocSymbol::Less:    c = '<'; break;
-  case DocSymbol::Greater: c = '>'; break;
-  case DocSymbol::Amp:     c = '&'; break;
-  case DocSymbol::Dollar:  c = '$'; break;
-  case DocSymbol::Hash:    c = '#'; break;
-  case DocSymbol::Percent: c = '%'; break;
-  case DocSymbol::Quot:    c = '"'; break;
-  case DocSymbol::Lsquo:   s = "\\\'"; break;
-  case DocSymbol::Rsquo:   s = "\\\'"; break;
-  case DocSymbol::Ldquo:   c = '"'; break;
-  case DocSymbol::Rdquo:   c = '"'; break;
-  case DocSymbol::Ndash:   c = '-'; break;
-  case DocSymbol::Mdash:   s = "--"; break;
-  case DocSymbol::Nbsp:    c = ' '; break;
-  case DocSymbol::Uml:     accent = "umlaut"; break;
-  case DocSymbol::Acute:   accent = "acute"; break;
-  case DocSymbol::Grave:   accent = "grave"; break;
-  case DocSymbol::Circ:    accent = "circ"; break;
-  case DocSymbol::Slash:   accent = "slash"; break;
-  case DocSymbol::Tilde:   accent = "tilde"; break;
-  case DocSymbol::Cedil:   accent = "cedilla"; break;
-  case DocSymbol::Ring:    accent = "ring"; break;
-  case DocSymbol::BSlash:  s = "\\\\"; break;
-  case DocSymbol::Copy:    symbol = "copyright"; break;
-  case DocSymbol::Tm:      symbol = "trademark"; break;
-  case DocSymbol::Reg:     symbol = "registered"; break;
-  case DocSymbol::Szlig:   symbol = "szlig"; break;
-  case DocSymbol::Apos:    s = "\\\'"; break;
-  case DocSymbol::Aelig:   symbol = "aelig"; break;
-  case DocSymbol::AElig:   symbol = "AElig"; break;
-  case DocSymbol::Unknown:
-    err("Error: unknown symbol found\n");
-    break;
+    case DocSymbol::At:      c = '@'; break;
+    case DocSymbol::Less:    c = '<'; break;
+    case DocSymbol::Greater: c = '>'; break;
+    case DocSymbol::Amp:     c = '&'; break;
+    case DocSymbol::Dollar:  c = '$'; break;
+    case DocSymbol::Hash:    c = '#'; break;
+    case DocSymbol::Percent: c = '%'; break;
+    case DocSymbol::Quot:    c = '"'; break;
+    case DocSymbol::Lsquo:   s = "\\\'"; break;
+    case DocSymbol::Rsquo:   s = "\\\'"; break;
+    case DocSymbol::Ldquo:   c = '"'; break;
+    case DocSymbol::Rdquo:   c = '"'; break;
+    case DocSymbol::Ndash:   c = '-'; break;
+    case DocSymbol::Mdash:   s = "--"; break;
+    case DocSymbol::Nbsp:    c = ' '; break;
+    case DocSymbol::Uml:     accent = "umlaut"; break;
+    case DocSymbol::Acute:   accent = "acute"; break;
+    case DocSymbol::Grave:   accent = "grave"; break;
+    case DocSymbol::Circ:    accent = "circ"; break;
+    case DocSymbol::Slash:   accent = "slash"; break;
+    case DocSymbol::Tilde:   accent = "tilde"; break;
+    case DocSymbol::Cedil:   accent = "cedilla"; break;
+    case DocSymbol::Ring:    accent = "ring"; break;
+    case DocSymbol::BSlash:  s = "\\\\"; break;
+    case DocSymbol::Copy:    symbol = "copyright"; break;
+    case DocSymbol::Tm:      symbol = "trademark"; break;
+    case DocSymbol::Reg:     symbol = "registered"; break;
+    case DocSymbol::Szlig:   symbol = "szlig"; break;
+    case DocSymbol::Apos:    s = "\\\'"; break;
+    case DocSymbol::Aelig:   symbol = "aelig"; break;
+    case DocSymbol::AElig:   symbol = "AElig"; break;
+    case DocSymbol::Unknown: err("error: unknown symbol found\n");
+                             break;
   }
-  if (c != 0) {
+  if (c != 0) 
+  {
     enterText();
     m_output.add(c);
-  } else if (s != 0) {
+  } 
+  else if (s != 0) 
+  {
     enterText();
     m_output.add(s);
-  } else if (symbol != 0) {
+  } 
+  else if (symbol != 0) 
+  {
     leaveText();
     openItem("symbol");
     m_output.addFieldQuotedString("symbol", symbol);
     closeItem();
-  } else if (accent != 0) {
+  } 
+  else if (accent != 0) 
+  {
     leaveText();
     openItem("accent");
     m_output
@@ -649,7 +646,7 @@ void PerlModDocVisitor::visit(DocVerbatim *s)
 
 void PerlModDocVisitor::visit(DocAnchor *anc)
 {
-  QString anchor = anc->file() + "_1" + anc->anchor();
+  QCString anchor = anc->file() + "_1" + anc->anchor();
   openItem("anchor");
   m_output.addFieldQuotedString("id", anchor);
   closeItem();
@@ -715,7 +712,7 @@ void PerlModDocVisitor::visit(DocIncOperator *)
 void PerlModDocVisitor::visit(DocFormula *f)
 {
   openItem("formula");
-  QString id;
+  QCString id;
   id += f->id();
   m_output.addFieldQuotedString("id", id).addFieldQuotedString("content", f->text());
   closeItem();
@@ -804,7 +801,7 @@ void PerlModDocVisitor::visitPre(DocSimpleSect *s)
   case DocSimpleSect::Version:		type = "version"; break;
   case DocSimpleSect::Since:		type = "since"; break;
   case DocSimpleSect::Date:		type = "date"; break;
-  case DocSimpleSect::Note:		type = "bug"; break;
+  case DocSimpleSect::Note:		type = "note"; break;
   case DocSimpleSect::Warning:		type = "warning"; break;
   case DocSimpleSect::Pre:		type = "pre"; break;
   case DocSimpleSect::Post:		type = "post"; break;
@@ -814,9 +811,11 @@ void PerlModDocVisitor::visitPre(DocSimpleSect *s)
   case DocSimpleSect::User:		type = "par"; break;
   case DocSimpleSect::Rcs:		type = "rcs"; break;
   case DocSimpleSect::Unknown:
-    err("Error: unknown simple section found\n");
+    err("error: unknown simple section found\n");
     break;
   }
+  leaveText();
+  m_output.openHash();
   openOther();
   openSubBlock(type);
 }
@@ -825,6 +824,7 @@ void PerlModDocVisitor::visitPost(DocSimpleSect *)
 {
   closeSubBlock();
   closeOther();
+  m_output.closeHash();
 }
 
 void PerlModDocVisitor::visitPre(DocTitle *)
@@ -857,7 +857,7 @@ void PerlModDocVisitor::visitPost(DocSimpleListItem *) { closeSubBlock(); }
 
 void PerlModDocVisitor::visitPre(DocSection *s)
 {
-  QString sect = QString("sect%1").arg(s->level());
+  QCString sect = QCString().sprintf("sect%d",s->level());
   openItem(sect);
   openSubBlock("content");
 }
@@ -1170,7 +1170,7 @@ void PerlModDocVisitor::visitPre(DocParamSect *s)
   case DocParamSect::Exception: type = "exceptions"; break;
   case DocParamSect::TemplateParam: type = "templateparam"; break;
   case DocParamSect::Unknown:
-    err("Error: unknown parameter section found\n");
+    err("error: unknown parameter section found\n");
     break;
   }
   openOther();
@@ -1356,10 +1356,10 @@ static const char *getVirtualnessName(Specifier virt)
   return 0;
 }
 
-static QString pathDoxyfile;
-static QString pathDoxyExec;
+static QCString pathDoxyfile;
+static QCString pathDoxyExec;
 
-void setPerlModDoxyfile(const QString &qs)
+void setPerlModDoxyfile(const QCString &qs)
 {
   pathDoxyfile = qs;
   pathDoxyExec = QDir::currentDirPath();
@@ -1371,18 +1371,18 @@ public:
 
   PerlModOutput m_output;
 
-  QString pathDoxyStructurePM;
-  QString pathDoxyDocsTex;
-  QString pathDoxyFormatTex;
-  QString pathDoxyLatexTex;
-  QString pathDoxyLatexDVI;
-  QString pathDoxyLatexPDF;
-  QString pathDoxyStructureTex;
-  QString pathDoxyDocsPM;
-  QString pathDoxyLatexPL;
-  QString pathDoxyLatexStructurePL;
-  QString pathDoxyRules;
-  QString pathMakefile;
+  QCString pathDoxyStructurePM;
+  QCString pathDoxyDocsTex;
+  QCString pathDoxyFormatTex;
+  QCString pathDoxyLatexTex;
+  QCString pathDoxyLatexDVI;
+  QCString pathDoxyLatexPDF;
+  QCString pathDoxyStructureTex;
+  QCString pathDoxyDocsPM;
+  QCString pathDoxyLatexPL;
+  QCString pathDoxyLatexStructurePL;
+  QCString pathDoxyRules;
+  QCString pathMakefile;
 
   inline PerlModGenerator(bool pretty) : m_output(pretty) { }
 
@@ -2035,7 +2035,7 @@ bool PerlModGenerator::generatePerlModOutput()
   if (!createOutputFile(outputFile, pathDoxyDocsPM))
     return false;
   
-  QTextStream outputTextStream(&outputFile);
+  FTextStream outputTextStream(&outputFile);
   PerlModOutputStream outputStream(&outputTextStream);
   m_output.setPerlModOutputStream(&outputStream);
   m_output.add("$doxydocs=").openHash();
@@ -2118,13 +2118,13 @@ bool PerlModGenerator::createOutputDir(QDir &perlModDir)
       dir.setPath(QDir::currentDirPath());
       if (!dir.mkdir(outputDirectory))
       {
-	err("Error: tag OUTPUT_DIRECTORY: Output directory `%s' does not "
+	err("error: tag OUTPUT_DIRECTORY: Output directory `%s' does not "
 	    "exist and cannot be created\n",outputDirectory.data());
 	exit(1);
       }
       else if (!Config_getBool("QUIET"))
       {
-	err("Notice: Output directory `%s' does not exist. "
+	err("notice: Output directory `%s' does not exist. "
 	    "I have created it for you.\n", outputDirectory.data());
       }
       dir.cd(outputDirectory);
@@ -2158,7 +2158,7 @@ bool PerlModGenerator::generateDoxyStructurePM()
   if (!createOutputFile(doxyModelPM, pathDoxyStructurePM))
     return false;
 
-  QTextStream doxyModelPMStream(&doxyModelPM);
+  FTextStream doxyModelPMStream(&doxyModelPM);
   doxyModelPMStream << 
     "sub memberlist($) {\n"
     "    my $prefix = $_[0];\n"
@@ -2343,9 +2343,9 @@ bool PerlModGenerator::generateDoxyRules()
     return false;
 
   bool perlmodLatex = Config_getBool("PERLMOD_LATEX");
-  QString prefix = Config_getString("PERLMOD_MAKEVAR_PREFIX");
+  QCString prefix = Config_getString("PERLMOD_MAKEVAR_PREFIX");
 
-  QTextStream doxyRulesStream(&doxyRules);
+  FTextStream doxyRulesStream(&doxyRules);
   doxyRulesStream <<
     prefix << "DOXY_EXEC_PATH = " << pathDoxyExec << "\n" <<
     prefix << "DOXYFILE = " << pathDoxyfile << "\n" <<
@@ -2440,9 +2440,9 @@ bool PerlModGenerator::generateMakefile()
     return false;
 
   bool perlmodLatex = Config_getBool("PERLMOD_LATEX");
-  QString prefix = Config_getString("PERLMOD_MAKEVAR_PREFIX");
+  QCString prefix = Config_getString("PERLMOD_MAKEVAR_PREFIX");
 
-  QTextStream makefileStream(&makefile);
+  FTextStream makefileStream(&makefile);
   makefileStream <<
     ".PHONY: default clean" << (perlmodLatex ? " pdf" : "") << "\n"
     "default: " << (perlmodLatex ? "pdf" : "clean") << "\n"
@@ -2466,7 +2466,7 @@ bool PerlModGenerator::generateDoxyLatexStructurePL()
   if (!createOutputFile(doxyLatexStructurePL, pathDoxyLatexStructurePL))
     return false;
 
-  QTextStream doxyLatexStructurePLStream(&doxyLatexStructurePL);
+  FTextStream doxyLatexStructurePLStream(&doxyLatexStructurePL);
   doxyLatexStructurePLStream << 
     "use DoxyStructure;\n"
     "\n"
@@ -2500,7 +2500,7 @@ bool PerlModGenerator::generateDoxyLatexPL()
   if (!createOutputFile(doxyLatexPL, pathDoxyLatexPL))
     return false;
 
-  QTextStream doxyLatexPLStream(&doxyLatexPL);
+  FTextStream doxyLatexPLStream(&doxyLatexPL);
   doxyLatexPLStream << 
     "use DoxyStructure;\n"
     "use DoxyDocs;\n"
@@ -2623,7 +2623,7 @@ bool PerlModGenerator::generateDoxyFormatTex()
   if (!createOutputFile(doxyFormatTex, pathDoxyFormatTex))
     return false;
 
-  QTextStream doxyFormatTexStream(&doxyFormatTex);
+  FTextStream doxyFormatTexStream(&doxyFormatTex);
   doxyFormatTexStream << 
     "\\def\\Defcs#1{\\long\\expandafter\\def\\csname#1\\endcsname}\n"
     "\\Defcs{Empty}{}\n"
@@ -2786,7 +2786,7 @@ bool PerlModGenerator::generateDoxyLatexTex()
   if (!createOutputFile(doxyLatexTex, pathDoxyLatexTex))
     return false;
 
-  QTextStream doxyLatexTexStream(&doxyLatexTex);
+  FTextStream doxyLatexTexStream(&doxyLatexTex);
   doxyLatexTexStream <<
     "\\documentclass[a4paper,12pt]{article}\n"
     "\\usepackage[latin1]{inputenc}\n"
