@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -23,15 +23,14 @@
 #include <qstack.h>
 #include <qcstring.h>
 
-class QTextStream;
+class FTextStream;
 class CodeOutputInterface;
-class QString;
 
 /*! @brief Concrete visitor implementation for RTF output. */
 class RTFDocVisitor : public DocVisitor
 {
   public:
-    RTFDocVisitor(QTextStream &t,CodeOutputInterface &ci,const char *langExt);
+    RTFDocVisitor(FTextStream &t,CodeOutputInterface &ci,const char *langExt);
     
     //--------------------------------------
     // visitor functions for leaf nodes
@@ -51,6 +50,7 @@ class RTFDocVisitor : public DocVisitor
     void visit(DocIncOperator *);
     void visit(DocFormula *);
     void visit(DocIndexEntry *);
+    void visit(DocSimpleSectSep *);
 
     //--------------------------------------
     // visitor functions for compound nodes
@@ -134,23 +134,23 @@ class RTFDocVisitor : public DocVisitor
     //--------------------------------------
     
     void filter(const char *str,bool verbatim=FALSE);
-    void startLink(const QString &ref,const QString &file,
-                   const QString &anchor);
-    void endLink(const QString &ref);
-    QString getStyle(const char *name);
+    void startLink(const QCString &ref,const QCString &file,
+                   const QCString &anchor);
+    void endLink(const QCString &ref);
+    QCString getStyle(const char *name);
     void incIndentLevel();
     void decIndentLevel();
 
     void pushEnabled();
     void popEnabled();
-    void writeDotFile(const QString &fileName);
-    void writeMscFile(const QString &fileName);
+    void writeDotFile(const QCString &fileName);
+    void writeMscFile(const QCString &fileName);
 
     //--------------------------------------
     // state variables
     //--------------------------------------
 
-    QTextStream &m_t;
+    FTextStream &m_t;
     CodeOutputInterface &m_ci;
     bool m_insidePre;
     bool m_hide;
