@@ -238,10 +238,10 @@ function SearchBox(name, resultsPath, inFrame, label)
       if (child.className=='SelectItem')
       {
         var node = child.firstChild;
-	if (j==id)
-	{
+        if (j==id)
+        {
           node.innerHTML='&bull;';
-        } 
+        }
         else
         {
           node.innerHTML='&nbsp;';
@@ -324,7 +324,7 @@ function SearchBox(name, resultsPath, inFrame, label)
     var resultsPageWithSearch;
     var hasResultsPage;
 
-    if (indexSectionsWithContent[this.searchIndex].charAt(code-32) == '1')
+    if (indexSectionsWithContent[this.searchIndex].charAt(code) == '1')
     {
        resultsPage = this.resultsPath + '/' + indexSectionNames[this.searchIndex] + '_' + hexCode + '.html';
        resultsPageWithSearch = resultsPage+'?'+escape(searchValue);
@@ -356,8 +356,8 @@ function SearchBox(name, resultsPath, inFrame, label)
        else
        {
          var domPopupSearchResults = this.DOMPopupSearchResults();
-         var left = getXPos(domSearchBox) + domSearchBox.offsetWidth;
-         var top  = getYPos(domSearchBox) + domSearchBox.offsetHeight + 1;
+         var left = getXPos(domSearchBox) + 150; // domSearchBox.offsetWidth;
+         var top  = getYPos(domSearchBox) + 20;  // domSearchBox.offsetHeight + 1;
          domPopupSearchResultsWindow.style.display = 'block';
          left -= domPopupSearchResults.offsetWidth;
          domPopupSearchResultsWindow.style.top     = top  + 'px';
@@ -453,20 +453,20 @@ function SearchResults(name)
       if (element)
       {
         if (element.style.display == 'block')
-        {  
-          element.style.display = 'none';  
+        {
+          element.style.display = 'none';
         }
         else
-        {  
-          element.style.display = 'block';  
+        {
+          element.style.display = 'block';
         }
       }
     }
 
-    // Searches for the passed string.  If there is no parameter, 
+    // Searches for the passed string.  If there is no parameter,
     // it takes it from the URL query.
     //
-    // Always returns true, since other documents may try to call it 
+    // Always returns true, since other documents may try to call it
     // and that may or may not be possible.
     this.Search = function(search)
     {
@@ -501,20 +501,20 @@ function SearchResults(name)
             matches++;
           }
           else
-          {  
-            row.style.display = 'none';  
+          {
+            row.style.display = 'none';
           }
         }
         i++;
       }
       document.getElementById("Searching").style.display='none';
       if (matches == 0) // no results
-      {  
-        document.getElementById("NoMatches").style.display='block';  
+      {
+        document.getElementById("NoMatches").style.display='block';
       }
       else // at least one result
-      {  
-        document.getElementById("NoMatches").style.display='none';  
+      {
+        document.getElementById("NoMatches").style.display='none';
       }
       this.lastMatchCount = matches;
       return true;
@@ -606,9 +606,9 @@ function SearchResults(name)
             while (1) // search for last child
             {
               tmpElem = document.getElementById('Item'+newIndex+'_c'+n);
-              if (tmpElem) 
+              if (tmpElem)
               {
-                focusItem = tmpElem; 
+                focusItem = tmpElem;
               }
               else // found it!
               {
