@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -204,52 +204,35 @@ ClassDef *VhdlDocGen::getClass(const char *name)
 }
 
 /*!
- * adds components to their entities
+ * adds architectures to their entity
  */
-void VhdlDocGen::computeVhdlComponentRelations(const QDict<EntryNav>& classEntries,FileStorage* g_storage)
+void VhdlDocGen::computeVhdlComponentRelations()
 {
   ClassSDict::Iterator cli(*Doxygen::classSDict);
-  for (cli.toFirst();cli.current();++cli) cli.current()->visited=FALSE;
-  QDictIterator<EntryNav> edi(classEntries);
-  EntryNav *rootNav;
-  for (;(rootNav=edi.current());++edi)
+  for (cli.toFirst();cli.current();++cli)
   {
-    ClassDef *cd;
-    rootNav->loadEntry(g_storage);
-    Entry *root = rootNav->entry();
-    QCString bName=stripAnonymousNamespaceScope(rootNav->name());
-    if ((cd=getClass(bName)))
+    cli.current()->visited=FALSE;
+    ClassDef * cd = cli.current();
+    if ((VhdlDocGen::VhdlClasses)cd->protection()==VhdlDocGen::ARCHITECTURECLASS || 
+        (VhdlDocGen::VhdlClasses)cd->protection()==VhdlDocGen::PACKBODYCLASS)
     {
-      QListIterator<BaseInfo> bii(*root->extends);
-      BaseInfo *bi=0;
-      for (bii.toFirst();(bi=bii.current());++bii)
+      QCString bName=cd->name();
+      int i=bName.find("::");
+      if (i>0)
       {
-	ClassDef* baseDef=getClass(bi->name);
-
-	if (baseDef && baseDef != cd)
-	{
-	  QCString cc=VhdlDocGen::getClassName(cd);
-	  ClassDef *ccdef=getClass(cc);
-	  if (ccdef==0) break;
-
-	  int ii=ccdef->protection();
-	  int jj=baseDef->protection();
-
-	  if (ii==VhdlDocGen::ENTITYCLASS && jj==VhdlDocGen::ENTITYCLASS && (ccdef !=baseDef))
-	  {
-	    ccdef->insertBaseClass(baseDef,bi->name,Public,Normal,0);
-	    baseDef->insertSubClass(ccdef,Public,bi->virt,0);
-	  }        
-	}
-	else 
-	{
-	  if (Config_getBool("WARNINGS"))
-	    warn(rootNav->fileDef()->fileName().data(),root->startLine, "found component without entity: [%s]",bi->name.data());
-	}
-      }//for 
-    }//if
-    rootNav->releaseEntry();
-  }// for
+        QCString entityName=bName.left(i);
+        entityName.stripPrefix("_");
+        ClassDef *classEntity=Doxygen::classSDict->find(entityName);
+        // entity for architecutre ?
+        if (classEntity)
+        {
+          // printf("\n entity %s  arch %s",entityName.data(),bName.data());
+          classEntity->insertBaseClass(cd,bName,Public,Normal,0);
+          cd->insertSubClass(classEntity,Public,Normal,0);
+        }
+      }
+    }
+  }
 } // computeVhdlComponentRelations
 
 
@@ -639,7 +622,7 @@ void VhdlDocGen::addFuncDoc(EntryNav* rootNav)
     if (!func && Config_getBool("WARNINGS"))
     {
       warn(root->fileName,root->docLine,
-      "Warning: documentation for unknown function %s found.\n",
+      "warning: documentation for unknown function %s found.\n",
       root->name.data()
       );
     }
@@ -1183,6 +1166,19 @@ void VhdlDocGen::getFuncParams(QList<Argument>& ql, const char* str)
   }//while
 } // getFuncName
 
+QCString VhdlDocGen::getProtectionName(int prot)
+{
+  if (prot==VhdlDocGen::ENTITYCLASS)
+    return "entity";
+  else if (prot==VhdlDocGen::ARCHITECTURECLASS)
+    return "architecture";
+  else if (prot==VhdlDocGen::PACKAGECLASS)
+    return "package";
+  else if (prot==VhdlDocGen::PACKBODYCLASS)
+    return "package body";
+
+  return "";
+}
 
 QCString VhdlDocGen::trTypeString(int type)
 {
@@ -1892,12 +1888,12 @@ void VhdlDocGen::writeVHDLDeclaration(MemberDef* mdef,OutputList &ol,
   }
 
   // write search index info
-  //if (Config_getBool("SEARCHENGINE"))
-  //{
-  //  Doxygen::searchIndex->setCurrentDoc(mdef->qualifiedName(),mdef->getOutputFileBase(),mdef->anchor());
-  //  Doxygen::searchIndex->addWord(mdef->localName(),TRUE);
-  //  Doxygen::searchIndex->addWord(mdef->qualifiedName(),FALSE);
-  //}
+  if (Doxygen::searchIndex)
+  {
+    Doxygen::searchIndex->setCurrentDoc(mdef->qualifiedName(),mdef->getOutputFileBase(),mdef->anchor());
+    Doxygen::searchIndex->addWord(mdef->localName(),TRUE);
+    Doxygen::searchIndex->addWord(mdef->qualifiedName(),FALSE);
+  }
 
   QCString cname  = d->name();
   QCString cfname = mdef->getOutputFileBase();
@@ -2224,7 +2220,7 @@ void VhdlDocGen::writeVHDLDeclarations(MemberList* ml,OutputList &ol,
 
   if (title) 
   {
-    ol.startMemberHeader();
+    ol.startMemberHeader(ml->listTypeAsString());
     ol.parseText(title);
     ol.endMemberHeader();
     ol.docify(" ");
